/**************************************************************************//**
 *
 * Copyright (C) 2011 Infineon Technologies AG. All rights reserved.
 *
 * Infineon Technologies AG (Infineon) is supplying this software for use with 
 * Infineon's microcontrollers.  
 * This file can be freely distributed within development tools that are 
 * supporting such microcontrollers. 
 *
 * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL, 
 * OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
********************************************************************************
**                                                                            **
**                                                                            **
** PLATFORM : Infineon XMC4000 Series   			                          **
**                                                                            **
** COMPILER : Compiler Independent                                            **
**                                                                            **
** AUTHOR   : App Developer                                                   **
**                                                                            **
** MAY BE CHANGED BY USER [yes/No]: Yes                                       **
**                                                                            **
** MODIFICATION DATE : Dec 12, 2012                                           **
**                                                                            **
*******************************************************************************/

/*******************************************************************************
**                       Author(s) Identity                                   **
********************************************************************************
**                                                                            **
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** NPJ        App Developer                                                   **
*******************************************************************************/

/**
 * @file DBG002_UART.h
 *
 * @brief  UART Header file for DBG002 App
 *
 */

#ifndef DBG002_UART_H_
#define DBG002_UART_H_

#ifdef __cplusplus
extern "C" {
#endif

/*******************************************************************************
**                      Include Files                                         **
*******************************************************************************/


#include <DAVE3.h>
#include "../../inc/DBG002/DBG002_Usic.h"


/*******************************************************************************
**                      Global Macro Definitions                              **
*******************************************************************************/

/**
 * @ingroup UART001_apidoc
 * @{
 */
/** 
 * Macro which writes a data word into the transmit FIFO buffer register. 
 * @param[in]  Handle  USIC device handle.
 * @param[in]  Data  Data to be transmitted.
 */
#define DBG002_UARTWriteData(Handle,Data) (Handle.UartRegs->IN[0] = Data)

/** 
 * Macro which reads a data word from the receive FIFO buffer register. 
 * @param[in]  Handle  USIC device handle.
 */
#define DBG002_UARTReadData(Handle)  ((uint16_t)Handle.UartRegs->OUTR)

/**
 * @}
 */
/*******************************************************************************
**                      Global Type Definitions                               **
*******************************************************************************/

/**
 * @ingroup UART001_publicparam
 * @{
 */

/**
 * @brief This data type describes the possible status values returned
 *  by functions.
 */
typedef enum DBG002_UARTStatusType
{
  /**
   * Indicates Flag is not set
   */
  /*
	GROUPID  #3
	MODULENAME = UART001
  */
  /*
	ERRCODESTRING = DBG002_UARTRESET
	STRCODESTRING = Flag is not set
  */
  DBG002_UARTRESET = 1,
  /**
   * Indicates Flag is set
   */
  /*
	ERRCODESTRING = DBG002_UARTSET
	STRCODESTRING = Flag is set
  */
  DBG002_UARTSET,
  /**
   * UART Busy
   */
  /*
	ERRCODESTRING = DBG002_UARTBUSY
	STRCODESTRING = Uart channel busy
  */
  DBG002_UARTBUSY,
  /**
   * Invalid parameter
   */
  /*
	ERRCODESTRING = DBG002_UARTINVALID_PARAM
	STRCODESTRING = Invalid parameter
  */
  DBG002_UARTINVALID_PARAM,
  /**
   * Unknown error
   */
  /*
	ERRCODESTRING = DBG002_UARTERROR
	STRCODESTRING = Uart Error
  */
  DBG002_UARTERROR,
  /**
   * Function Entry
   */
  /*
	ERRCODESTRING = DBG002_UARTFUN_ENTRY
	STRCODESTRING = Entered function %s
  */
  DBG002_UARTFUN_ENTRY,
  /**
   *  Function Exit
   */
  /*
	ERRCODESTRING = DBG002_UARTFUN_EXIT
	STRCODESTRING = Exited function %s
  */
  DBG002_UARTFUN_EXIT
  /*
	ERRORCODEEND
  */
}DBG002_UARTStatusType;


/**
 * @brief This data type describes UART App instance handle details
 */
 typedef struct DBG002_UARTHandleType
{
  /** CMSIS defined structure for USIC module */
  USIC_CH_TypeDef* UartRegs;
  /** USIC Operation mode */
  UART_ModeType Mode;
  /** No of stopbit selected */
  UART_StopBitType StopBit;
  /** Parity  selected */
  UART_ParityType Parity;
  /** Desired baud rate */
  uint32_t BaudRate;
  /** Word Length */
  uint16_t DataBits;
  /** TX FIFO Trigger value */
  uint8_t TxLimit;
  /** RX FIFO Triger value */
  uint8_t RxLimit;
  /** Tx FIFO Size value */
  uint8_t TxFifoSize;
  /** Rx FIFO Size value */
  uint8_t RxFifoSize;
  /** Calculated step value */
  uint16_t BGR_STEP;
  /** Calculated pdiv value */
  uint16_t BGR_PDIV;
  /** Calculated  dctq value */
  uint16_t BGR_DCTQ;
  /** Calculated  sampling point value */
  /** SP = (((1+dctq)/2)+1) */
  uint16_t BGR_SP;
  /** Calculated  pctq value */
  uint8_t BGR_PCTQ;  
}DBG002_UARTHandleType;

/**
 * @}
 */
/*******************************************************************************
**                      Global Constant Declarations                          **
*******************************************************************************/


/*******************************************************************************
**                      Extern Variables                                      **
*******************************************************************************/
/**
 * @ingroup UART001_apidoc
 * @{
 */

/*******************************************************************************
** FUNCTION PROTOTYPES                                                        **
*******************************************************************************/

/**
 * @brief Initializes all the UART channel registers consumed by UART001 App. All the UART001
 * App instances are configured as per the UI configuration.
 *
 * @return     None
 *
 * <b>Reentrant: NO </b><BR>
 * <b>Sync/Async:  Synchronous</b>
 * <BR><P ALIGN="LEFT"><B>Example:</B>
 * <BR><I><b>UART001_Handle0</b></I> is a global structure of type
 * DBG002_UARTHandleType which will be configured in DBG002_UARTConf.c file using
 * UI parameters.
 * @code
 *  #include <DAVE3.h>
 *
 *  int main(void)
 *  {
 *	  // ... Initializes Apps configurations ...
 *    DAVE_Init(); // DBG002_UARTInit() will be called inside DAVE_Init()
 *    while(1)
 *    {
 *
 *    }
 * }
 * @endcode<BR> </p>
 *
 */
void  DBG002_UARTInit (void);

/**
 *@}
 */
 
/* Include App config file */
#include "DBG002_UARTConf.h"

#ifdef __cplusplus
}
#endif

#endif /* DBG002_UART_H_ */
