/*
 * I.c - support for invariants (assertions) using C code. 
 *
 * Copyright (c) 1997 Phil Maker
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * Id: I.c,v 1.1.1.1 1997/11/23 11:45:50 pjm Exp 
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "I.h"
#include <DAVE3.h>
#include <assert.h>

#if (DBG002_INVARIENT_ASSERTION == 0)
extern void DBG002_Abort(void);
#endif

#if (DBG002_INVARIENT_ASSERTION == 1)
static void __BKPT( void );
#endif

/*
 * _I_default_handler - the default handler for assertion failures.
 *
 * Notes: 
 *
 *       o Generates GNU standard file/line error messages
 *         suitable for the compile command in emacs.
 *       o The handler dumps core since you are probably using a 
 *	   debugger. If you don't want the core dump I'd suggest
 *	   you use "ulimit" to disable core dumps rather than
 *	   changing this.
 */

void _I_default_handler(char *exprn, char *file, int line,int param)
{
#if (DBG002_INVARIENT_ASSERTION == 0)
    /** abort the execution */
	DBG002_Abort();
#elif (DBG002_INVARIENT_ASSERTION == 1)
    /** insert break instruction */
    __BKPT();
#elif (DBG002_INVARIENT_ASSERTION == 2)
    uint8_t message[256];
    uint8_t message_length = 4; // Line number 4 bytes
    char message_char;

    *((uint32_t*)message) = line;

    while((message_char = *(file++)) != 0 && message_length < 255) {
       message[message_length++] = message_char;
    }
    message[message_length++] = 0;

    while((message_char = *(exprn++)) != 0 && message_length < 255) {
       message[message_length++] = message_char;
    }
    message[message_length++] = 0;


#if (DBG002_PBC_MSG_SEVERITY == DBG002_LEVEL_TRACE)
    DBG002_Logging(DBG002_LEVEL_TRACE,param,DBG002_MESSAGEID_PBC, message_length,message);
#elif (DBG002_PBC_MSG_SEVERITY == DBG002_LEVEL_INFO)
    DBG002_Logging(DBG002_LEVEL_INFO,param,DBG002_MESSAGEID_PBC, message_length,message);
#elif (DBG002_PBC_MSG_SEVERITY == DBG002_LEVEL_WARNING)
    DBG002_Logging(DBG002_LEVEL_WARNING,param,DBG002_MESSAGEID_PBC, message_length,message);
#elif (DBG002_PBC_MSG_SEVERITY == DBG002_LEVEL_ERROR)
    DBG002_Logging(DBG002_LEVEL_ERROR,param,DBG002_MESSAGEID_PBC, message_length,message);
#elif (DBG002_PBC_MSG_SEVERITY == DBG002_LEVEL_CRITICAL)
    DBG002_Logging(DBG002_LEVEL_CRITICAL,param,DBG002_MESSAGEID_PBC, message_length,message);
#elif (DBG002_PBC_MSG_SEVERITY == DBG002_LEVEL_SAFETY_CRITICAL)
    DBG002_Logging(DBG002_LEVEL_SAFETY_CRITICAL,param,DBG002_MESSAGEID_PBC, message_length,message);
#else
    /* No Code */
#endif
#endif
}

#if (DBG002_INVARIENT_ASSERTION == 1)
  #if defined(__CC_ARM)
  __asm void __BKPT(void)
  {
    bkpt #0
  }
  #elif defined(__ICCARM__)
  void __BKPT(void)
  {
    asm("bkpt #0");
  }
  #elif defined(__GNUC__)
  void __BKPT(void)
  {
    asm("bkpt #0");
  }
  #elif defined(__TASKING__)
  void __BKPT(void)
  {
    __asm("bkpt #0");
  }
  #endif
#endif
