/*******************************************************************************
 Copyright (c) 2014, Infineon Technologies AG                                 **
 All rights reserved.                                                         **
                                                                              **
 Redistribution and use in source and binary forms, with or without           **
 modification,are permitted provided that the following conditions are met:   **
                                                                              **
 *Redistributions of source code must retain the above copyright notice,      **
 this list of conditions and the following disclaimer.                        **
 *Redistributions in binary form must reproduce the above copyright notice,   **
 this list of conditions and the following disclaimer in the documentation    **
 and/or other materials provided with the distribution.                       **
 *Neither the name of the copyright holders nor the names of its contributors **
 may be used to endorse or promote products derived from this software without**
 specific prior written permission.                                           **
                                                                              **
 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"  **
 AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE    **
 IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE   **
 ARE  DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE   **
 LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR         **
 CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF         **
 SUBSTITUTE GOODS OR  SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS    **
 INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN      **
 CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)       **
 ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE   **
 POSSIBILITY OF SUCH DAMAGE.                                                  **
                                                                              **
 To improve the quality of the software, users are encouraged to share        **
 modifications, enhancements or bug fixes with Infineon Technologies AG       **
 dave@infineon.com).                                                          **
                                                                              **
********************************************************************************
**                                                                            **
** PLATFORM : Infineon XMC4000/XMC1000 Series                                 **
**                                                                            **
** COMPILER : Compiler Independent                                            **
**                                                                            **
** AUTHOR   : DAVE App Developer                                              **
**                                                                            **
** MAY BE CHANGED BY USER [yes/no]: Yes                                       **
**                                                                            **
** NOTE     : Any Changes made to this file will be overwritten during Code   **
**            Generation                                                      **
**                                                                            **
********************************************************************************
** VERSION HISTORY:
********************************************************************************
** 03 May   2013   v1.0.0    Initial version
** 24 July  2013   v1.0.6    Added Support for XMC4400 device,Trap interrupt 
**                           init code generation issue solved and help document
**                           updated.
** 23 Sept  2013   v1.0.8    DBG002 Macro Updated
** 26 Nov   2013   v1.0.10   Added FOC Support for XMC45 & 42 Devices
** 30 Jan   2014   v1.0.12   Updated PMSMFOCSL01.c and PMSMFOCSL01.h as static 
**                           files.
**                           BootStrap function added.
**                           XMC1000 VQFN package support added. 
**                           XMC4000 Device support extended for XMC4500 AC step, 
**                           XMC4400 AB Step and XMC4200 AB Step.
**                           DBG002 related MACRO has been updated.
*******************************************************************************/

/**
 * @file PMSMFOCSL01.h
 *
 * @brief This file contains the data structures and the function prototypes of the 
 * PMSMFOCSL01 App. 
 */

#ifndef PMSMFOCSL01_H_
#define PMSMFOCSL01_H_

/* Support for C++ codebase */
#ifdef __cplusplus
extern "C" {
#endif

/*******************************************************************************
** INCLUDE FILES:
*******************************************************************************/
#include <DAVE3.h>
#include <uc_id.h>

#if (__TARGET_DEVICE__ == XMC45)
#include <XMC4500.h>
#elif (__TARGET_DEVICE__ == XMC44)
#include <XMC4400.h>
#elif ((__TARGET_DEVICE__ == XMC42) ||(__TARGET_DEVICE__ == XMC41) )
#include <XMC4200.h>
#elif (__TARGET_DEVICE__ == XMC11)
#include <XMC1100.h>
#elif (__TARGET_DEVICE__ == XMC12)
#include <XMC1200.h>
#elif (__TARGET_DEVICE__ == XMC13)
#include <XMC1300.h>

#else

#error "Unsupported XMC family"

#endif

/*******************************************************************************
** GLOBAL MACRO DEFINITIONS: 										
*******************************************************************************/
/**
  * @ingroup PMSMFOCSL01_constants
  * @{
*/

/* Motor Status macros */
#define   PMSMFOCSL01_OFF_Pos    (0U)
#define   PMSMFOCSL01_OFF_Msk    (0x00000001U  << PMSMFOCSL01_OFF_Pos)

#define   PMSMFOCSL01_ON_Pos      (1U)
#define   PMSMFOCSL01_ON_Msk      (0x00000001U  << PMSMFOCSL01_ON_Pos)

#define   PMSMFOCSL01_RAMP_Pos    (2U)
#define   PMSMFOCSL01_RAMP_Msk    (0x00000001U  << PMSMFOCSL01_RAMP_Pos)

#define   PMSMFOCSL01_TRAP_Pos    (4U)
#define   PMSMFOCSL01_TRAP_Msk    (0x00000001U  << PMSMFOCSL01_TRAP_Pos)

#define   PMSMFOCSL01_FOC_Pos    (5U)
#define   PMSMFOCSL01_FOC_Msk    (0x00000001U  << PMSMFOCSL01_FOC_Pos)

#define   PMSMFOCSL01_OL_Pos    (6U)
#define   PMSMFOCSL01_OL_Msk    (0x00000001U  << PMSMFOCSL01_OL_Pos)

#define   PMSMFOCSL01_BS_Pos     (9U)
#define   PMSMFOCSL01_BS_Msk     (0x00000001U  << PMSMFOCH03_BS_Pos)

#define   PMSMFOCSL01_POWER215    (32767U)

#define   PMSMFOCSL01_TRUE            (1U)
#define   PMSMFOCSL01_FALSE           (0U)
#define   PMSMFOCSL01_SIGNED_ONE      (-1)
#define   PMSMFOCSL01_ADCCAL_COUNT   (16U)

/* This macro value is used for V/F value scaling */
#define   PMSMFOCSL01_VFSCALE               (8U)

/* This macro value is used for scaling the potentiometer value for input
 * speed values calculation*/
#define  PMSMFOCSL01_POTSCALE             (10U)

/*These macro values are used in API functions for scaling*/
#define  PMSMFOCSL01_SPEED_SCALE        (15U)

/*These macro values are used to define motor direction*/
#define  PMSMFOCSL01_MOTOR_DIR_FORWARD     (1)
#define  PMSMFOCSL01_MOTOR_DIR_REVERSE     (-1)

#define PMSMFOCSL01_INTEGRALBUF_MASK   0x7FF0000

#define PMSMFOCSL01_7SEGSYM    (0U)
#define PMSMFOCSL01_7SEGASYM   (1U)
#define PMSMFOCSL01_5SEGSYM    (2U)
#define PMSMFOCSL01_5SEGASYM   (3U)
#define PMSMFOCSL01_PSEUDO3V   (4U)
#define PMSMFOCSL01_PSEDO4V    (5U)

#define PMSMFOCSL01_RESISTANCESCALE (16U)
#define PMSMFOCSL01_INDUCTANCESCALE (17U)

#define PMSMFOCSL01_AMPSCALE   (12U)

#define PMSMFOCSL01 1

#define USE_MOTORLIBS

/**
 * @}
 */

/*******************************************************************************
 *                                ENUMERATIONS                                **
 ******************************************************************************/
 
/**
 * @ingroup PMSMFOCSL01_enumerations
 * @{
 */
 
/**
 * This enumerates the error codes of the App which can occur at run-time.
 */
typedef enum PMSMFOCSL01_ErrorType
{
  /**
   * This indicates that the function execution is not allowed in the current 
   * App State.
   */
  /*
   * ERRCODESTRING = PMSMFOCSL01_OPERATION_NOT_ALLOWED
   * STRCODESTRING = Function execution is not allowed in the current state
   */
  PMSMFOCSL01_OPERATION_NOT_ALLOWED = 1,
  /**
   * This indicates that input parameter is out of range.
   */
  /*
   * ERRCODESTRING = PMSMFOCSL01_INVALID_PARAM
   * STRCODESTRING = Input argument is not valid
   */
  PMSMFOCSL01_INVALID_PARAM,
  /**
   * This indicates that trap condition is detected.
   */
  /*
   * ERRCODESTRING = PMSMFOCSL01_TRAP_ERROR
   * STRCODESTRING = trap condition is detected
   */
  PMSMFOCSL01_TRAP_ERROR,
  /**
   * This indicates that over current is detected.
   */
  /*
   * ERRCODESTRING = PMSMFOCSL01_OVRCURRENT
   * STRCODESTRING = over current condition is detected
   */
  PMSMFOCSL01_OVRCURRENT,
  /**
   * Function Entry
   */
  /*
   * ERRCODESTRING = PMSMFOCSL01_FUN_ENTRY
   * STRCODESTRING = Entered function %s
   */
  PMSMFOCSL01_FUN_ENTRY,
  /**
   *  Function Exit
   */
  /*
   * ERRCODESTRING = PMSMFOCSL01_FUN_EXIT
   * STRCODESTRING = Exited function %s
   */
  PMSMFOCSL01_FUN_EXIT

}PMSMFOCSL01_ErrorType;

/**
 * This enumerates the state of the App.
 */
typedef enum PMSMFOCSL01_StateType
{
  /**
  * This is the default state after power on reset. App goes to UNINITIALIZED
  * state after execution of the Deinit function.
  */
  PMSMFOCSL01_UNINITIALIZED,
  /**
  * App is in INITIALIZED state after execution of the Init function
  */           
  PMSMFOCSL01_INITIALIZED,
  /**
  * App is doing bootstrapping
  */
  PMSMFOCSL01_BOOTSTRAP,  
  /**
   * App is in OPENLOOP state after execution of start function if V/F startup 
   * is enabled. 
   */
  PMSMFOCSL01_OPENLOOP,
  /**
   * App is in RUNNING state after execution of the Start function if V/F 
   * startup is disabled or it goes in the RUNNING state after motor reaches 
   * the speed threshold value 
   */
  PMSMFOCSL01_RUNNING,
  /**
   * App is in STOPPED state after execution of the Stop function.
   */
  PMSMFOCSL01_STOPPED,

}PMSMFOCSL01_StateType;


/**
 * This enumerates the motor direction
 */
 typedef enum PMSMFOCSL01_MotDirType
 {
   /**
   * This enumerates reverse direction 
   */
   PMSMFOCSL01_REVDIR      = -1,
   /**
    * This enumerates forward direction
    */
   PMSMFOCSL01_FORDIR      = 1,
 
 }PMSMFOCSL01_MotDirType;

/**
 * @}
 */

/*******************************************************************************
 *                             STRUCTURES                                     **
 ******************************************************************************/
 
/**
  * @ingroup PMSMFOCSL01_datastructures
  * @{
  */
   
/**
 * This structure holds the control parameters of PMSMFOCSL01 App.
 */
typedef struct PMSMFOCSL01_ControlFlag
{
  /**
   * This saves whether POT is used for speed reference \n
   * 0: POT disabled \n
   * 1: POT enabled \n
   */
  uint32_t  Pot;
  /**
   * This saves whether Voltage Compensation feature is enabled. \n
   * 0: VoltageComp is disabled \n
   * 1: VoltageComp is enabled \n
  */
  uint32_t  VoltageComp;
  /**
   * This saves whether V/F Startup feature is enabled. \n
   * 0: V/FStartup is disabled \n
   * 1: V/FStartup is enabled \n
   */
  uint32_t  VFStartup;
  
  /**
   * This saves whether trap feature is enabled. \n
   * 0: Trap is disabled \n
   * 1: Trap is enabled \n
  */
  uint8_t  Trap;
 
}PMSMFOCSL01_ControlFlag;


/**
 * This structure holds the motor startup parameters 
 */
typedef struct PMSMFOCSL01_StartupHandleType
{
 /**This is the V/F offset value*/
  uint32_t 	VFOffset;
  /**This hold the V/F constant value*/
  uint32_t	VFConst;
  /**This hold the V/F angle*/
  int16_t	Angle;
}PMSMFOCSL01_StartupHandleType;

/**
 * This structure holds the FOC parameters which change at run
 * time.
 */      
typedef struct PMSMFOCSL01_DynamicHandleType
{
  /**
   * This holds the actual motor phase A current value
   */
  int32_t Ia;
  /**
   * This holds the actual motor phase B current value
   */
  int32_t Ib;
  /**
   * This holds the actual motor phase C current value
   */
  int32_t Ic;
  /**
   * This holds the current component in stationary orthogonal reference frame 
   * on alpha axis.
   */
  int32_t Ialpha;
  /**
   * This holds the current component in stationary orthogonal reference frame 
   * on beta axis.
   */
  int32_t Ibeta;
  /**
   * This holds the direct axis current component in rotor reference frame
   */
  int32_t Id;
  /**
   * This holds the quadrature axis current component in rotor reference frame
   */
  int32_t Iq;
  /**
   * This holds the direct axis current component reference value
   */
  int32_t IdRef;
  /**
   * This holds the quadrature axis current component reference value
   */
  int32_t IqRef;
  /**
   * This holds the quadrature axis current component initial value
   */
  uint32_t IqStartup;
  /**
    * This holds the Flux component in stationary orthogonal reference frame on 
    * alpha axis.
    */
  int32_t FluxAlpha;

  //
  int32_t EAlpha;//////dodao 30.10
  int32_t E;
  int32_t EBeta;  ////// 30.10
  int32_t MotorSpeedR; ////// 30.10
  int32_t Xc; ////// 30.10
  int32_t Ys; ///// 30.10
  int16_t FluxAngle1;  //// 31.10

  //
  /**
  * This holds the Flux component in stationary orthogonal reference frame on 
  * beta axis.
  */
  int32_t FluxBeta;
  /**
  * This holds the total Flux component .
  */
  uint32_t FluxAmp;
  /**
  * This holds the  Flux angle Value .
  */
  int16_t FluxAngle;
  /**
  * This holds the Previous Flux angle Value used for Speed Calculation .
  */
  int16_t FluxAngleStore;
  /**
   * This holds the Voltage component in stationary orthogonal reference frame 
   * on alpha axis.
   */
  int32_t Valpha;
  /**
   * This holds the Voltage component in stationary orthogonal reference frame on 
   * beta axis.
   */
  int32_t Vbeta;
  /**
   * This holds the direct axis voltage component in rotor reference frame
   */
  int32_t Vd;
  /**
   * This holds the quadrature axis voltage component in rotor reference frame
   */
  int32_t Vq;
  /**
   * This holds the DC link positive current value   
   */
  int32_t PositiveCurrent;
  /**
   * This holds the DC link negative  current value 
   */
  int32_t  NegativeCurrent;
  /**
   * This holds the speed control rate 
   */
  uint32_t SpeedControlRate;
  /**
   * This holds the current control rate 
   */
  uint32_t CurrentControlRate;
  /** 
   * This is the actual motor speed used in speed measurement.
   */
  int32_t MotorSpeed;
  /**
   * This holds the actual dc link voltage used in voltage compensation.
   */
  uint32_t ActVolt;
  /**
   * This is amplitude value which controls the voltage applied to motor.
   */
  uint32_t Amplitude;
  /**
   * This is the rotor angle.
   */
  int16_t Angle;
  /**
   * This is ramp scheduler its value is incremented for every time 
   * speed ramp is called and it will get reset when its value reaches ramp
   * counter.
   */
  uint32_t RampScheduler;
  /**
   * This is intermediate speed reference value during ramping state.
   */
  int32_t SpeedRef;
  /**
   * This is the target start speed reference value
   */
  int32_t StartSpeedRef;
  /**
   * This is the target end speed reference value.
   */
  int32_t EndSpeedRef;
  /**
   * This is the speed threshold value at which motor switches from open loop to
   * closed loop.
   */
  int32_t SpeedThreshold;
  /**
   * This is the Motor direction value.
   */
  int32_t MotorDirection;
  /**
   * This is the previous sector Value
   */
  uint16_t SectorStore;
  /**
   * Dynamic Current Amplifier Offset Value
   */
  uint32_t AmpOffset;	
   /**
    * This is the ramp counter value.
    * This is target value for slew rate.
    */
  uint32_t RampCounter;
   /**
    * This parameter holds the status of the motor. \n
    * LSB 0th bit position is OFF. \n
    * LSB 1st bit position is ON. \n
    * LSB 2nd bit position is RAMP. \n
    * LSB 4th bit position is Trap. \n
    * LSB 5th bit position is FOC enabled. \n
    * LSB 6th bit position is Open Loop.   \n 
    * LSB 9th bit position is Bootstrap.   \n */
  /**
   |---------------------------------------------------------------------------| \n
   | - | - | - | - | - | - | BS | - | - | OL | FOC| Trap | - | RAMP | ON | OFF | \n
   |---------------------------------------------------------------------------|*/
  
  volatile uint32_t   MotorStatus;
  /**
   * This variable counts number of period match for bootstrap timing.
   */
  uint32_t BootCount;  
  /**
   * This is the state of the App
   */
  volatile PMSMFOCSL01_StateType State;  
  
}PMSMFOCSL01_DynamicHandleType;

/**
 * This structure holds the GUI configurable parameters of this App.
 */
typedef struct PMSMFOCSL01_HandleType
{
  /**
   * This is the pointer to the PWMSVM01 App handle which is used to
   *  configure the SVM Parameters.
   */
  const PWMSVM01_HandleType* SVMAppPtr;
  /**
   * This is the pointer to the PMSMFOCSL01_DynamicHandleType which is used
   *  to configure the Dynamic parameters of PMSMFOCSL01.
   */
  PMSMFOCSL01_DynamicHandleType* H_Ptr;
  /**
   * This is the pointer to PMSMFOCSL01_StartupHandleType which is used to
   *  configure the foc startup Parameters.
   */
  PMSMFOCSL01_StartupHandleType* StartupHPtr;
  /**
   * This is the pointer to the MOTORLIBS_PIHandleType which is used
   *  to configure the Speed PI controller variables.
   */
  MOTORLIBS_PIHandleType* SpeedPIPtr;
  /**
   * This is the pointer to the MOTORLIBS_PIHandleType which is used
   *  to configure the Current Iq  PI controller variables.
   */
  MOTORLIBS_PIHandleType* IqPIPtr;
  /**
   * This is the pointer to the MOTORLIBS_PIHandleType which is used
   *  to configure the Current Id  PI controller variables.
   */
  MOTORLIBS_PIHandleType* IdPIPtr;

  //30.10.2016.
  MOTORLIBS_PIHandleType* PLLPIPtr;


  /**
   * This is the pointer to the PT1 Handler used for voltage compensation.
   */
  MOTORLIBS_PT1HandleType* VoltCompPT1Ptr;
  /**
   * This is the pointer to the PT1 Handler used for speed.
   */
  MOTORLIBS_PT1HandleType* SpeedPT1Ptr;
  /**
   * This is the pointer to the PT1 Handler used for Valpha.
   */
  MOTORLIBS_PT1HandleType* ValphaPT12Ptr;
  /**
   * This is the pointer to the PT1 Handler used for Vbeta.
   */
  MOTORLIBS_PT1HandleType* VbetaPT12Ptr;


  //30.10.2016.
  MOTORLIBS_PT1HandleType* PLLPT12Ptr;
  //

  /**
   * This is the pointer to the ADC002 App handle which is used to 
   * configure the ADC parameters for current measurement.
   */
  const ADC002_HandleType* ADCReqSrcPtrA; 
  /**
   * This is the pointer to the ADC002 App handle which is used to 
   * configure the ADC parameters for voltage compensation.
   */
  const ADC002_HandleType* ADCReqSrcPtrB; 
  /**
   * This is the pointer to the ADC002 App handle which is used to 
   * configure the ADC parameters for pot measurement.
   */
  const ADC002_HandleType* ADCReqSrcPtrC;
  /**
   * This is the voltage normalisation factor for target based on
   * GUI configuration
   */
  uint32_t kNormVolt;
  /**
   * This is the Alpha and Beta coordinate voltage normalisation factor for 
   * target
   */
  uint32_t kNormVoltAlphaBeta;
  /**
   * This is the Direct and Quadrature coordinate voltage normalisation factor
   * for target.
   */
  uint32_t kNormVoltdq;
  /**
   * This is normalised speed kp value for speed control technique
   */
  uint32_t  kNormkp;
  /**
   * This is normalised speed ki value
   */
  uint32_t  kNormki;
  /**
   * This is the speed normalisation factor for target based on
   * GUI configuration
   */
  int32_t kNormSpeed;
  /**
   * This is the current normalisation factor.
   */
  uint32_t kNormCurrent;
  /**
   * This is the Alpha and Beta coordinate Current normalisation factor for 
   * target
   */
  uint32_t kNormCurrentAlphaBeta;
  /**
   * This is the Direct and Quadrature coordinate voltage normalisation factor
   * for target
   */
  uint32_t kNormCurrentdq;
  /**
   * This is the speed normalisation factor for target based on
   * GUI configuration
   */
  uint32_t kNormSlewRate;
  /**
   * This is Maximum amplitude value.
   */
  uint32_t kAmplitudeMax;
  /**
   * This is Minimum amplitude value.
   */
  uint32_t kAmplitudeMin;
  /**
   * This is user start speed reference value based on GUI configuration
   */
  int32_t kUserStartSpeedRef;
  /**
   * This is speed threshold value at which motor is switched from open loop to
   * closed loop
   */
  int32_t kUserStartSpeedThreshold;
  /**
   * This is user end speed reference value based on GUI configuration
   */
  int32_t kUserEndSpeedRef;
  /**
   * This is the reference for the maximum target speed
   */
  uint32_t kSpeedMaxTarget;
  /**
   * This is the ramp counter value based on the user configuration
   */
  uint32_t kRampCounter;
  /**
   * This parameter holds the slew rate value
   */
  uint32_t kSlewRate;
  /**
   * This is the specified dc link voltage
   */
  uint32_t kSpecifiedVolt;
  /**
   * This is the number of pole pairs
   */
  uint32_t  kPolePair;
  /**
   * This is the scale value for the pot measurement.
   */
  uint32_t kPotScaleVal;
  /**
   * This holds the motor phase resistance value
   */
  uint32_t kMotorResistance;
  /**
   * This holds the motor phase resistance scaling value
   * Resistance value = kMotorResistance*kResistanceScale
   */  
  int32_t kResistanceScale;
  /**
   * This holds the motor phase inductance value
   */
  uint32_t kMotorInductance;
  /**
   * This holds the motor phase inductance scaling value
   * inductance value = kMotorInductance*kInductanceScale
   */  
  int32_t kInductanceScale;
  /**
   * This holds the speed control rate. Speed is calculated every 
   * kSpeedControlRate number of times of the PWM period match interrupt.
   */
  uint32_t kSpeedControlRate;
  /**
   * This hold the current control rate. FOC control loop is executed every 
   * kCurrentControlRate number of times of the PWM period match interrupt.
   */
  uint32_t kCurrentControlRate;
  /**
   * Holds the motor direction
   */
  int32_t kMotDirection;
  /**
   * Holds Amplitude Scaling values
   */
  uint32_t kAmplitudeScale;
  /**
   * Current Amplifier Offset Value
   */
  uint32_t kAmpOffset;
  /**
   * This saves whether Amplifier Bias Voltage Calibration is needed
   */
  uint32_t kAmpBiasVoltCal;
  /**
   * This will select the interrupt selection based on SVM configuration
   */
  uint32_t kCCRIntSelect;
  /**
   * Holds the control parameters of PMSMFOCSL01 App.
   */
  PMSMFOCSL01_ControlFlag  Enable;
  /**
   * This variable tells bootstrap count value.
   */
  uint32_t kBootStrapCount;
  /**
   * This tells whether bootstrap feature enabled or disabled.
   */
  uint32_t kBootStrapEnable;
  /**
   * This tells Time out function enabled or not
   */  
 
}PMSMFOCSL01_HandleType;

/**
 * This structure holds the configuration parameters for interrupt.
 */
typedef struct PMSMFOCSL01_ISRHandleType
{     
  /**
   * This is the node id for interrupt.
   */
  uint16_t Node_Id; 
  /**
   * This is the priority for interrupt.
   */
  uint16_t Priority;
  /**
   * This is the sub priority for the interrupt.
   */
  uint16_t Sub_Pri;    
      
}PMSMFOCSL01_ISRHandleType;  

/**
* @}
*/

/**
 * @ingroup PMSMFOCSL01_apidoc
 * @{
 */
     
/*******************************************************************************
								FUNCTION PROTOTYPES
*******************************************************************************/
  /**
  * @brief This function initialises PMSMFOCSL01 App and its dependent Apps. 
  * This is called by DAVE_Init.
  *  
  * @return void
  * <BR>
  *
  * <b>Reentrancy:  Yes</b><BR>
  * <b>Sync/Async:  Synchronous</b><BR>
  * @code
    #include <DAVE3.h>
    int main (void)
    {
      DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
      while(1);
      return 0;
    }
  * @endcode 
  */
  void PMSMFOCSL01_Init(void);

  /**
  * @brief This function starts the motor and sets the App state to RUNNING.
  * @param[in] HandlePtr Handle of the PMSMFOCSL01 App
  * @return <b>status_t</b><BR>
  * DAVEApp_SUCCESS: if the function is successful<BR>
  * PMSMFOCSL01_OPERATION_NOT_ALLOWED : If the function is called from
  * PMSMFOCSL01_UNINITIALIZED or PMSMFOCSL01_RUNNING State.<BR> 
  * <BR>
  *
  * <b>Reentrancy:  Yes</b><BR>
  * <b>Sync/Async:  Synchronous</b><BR>
  * @code
    #include <DAVE3.h>
    int main (void)
    {
      status_t Status;
      DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
      Status = PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
      while(1);
      return 0;
    }
  * @endcode 
  */
  status_t PMSMFOCSL01_MotorStart (const PMSMFOCSL01_HandleType* HandlePtr);
  /**
  * @brief This function stops the motor and sets the App state to STOPPED.
  * @param[in] HandlePtr Handle of the PMSMFOCSL01 App
  * @return <b>status_t</b><BR>
  * DAVEApp_SUCCESS: if the function is successful<BR>
  * PMSMFOCSL01_OPERATION_NOT_ALLOWED : If the function is called from
  * PMSMFOCSL01_UNINITIALIZED State.<BR> 
  * <BR>
  *
  * <b>Reentrancy:  Yes</b><BR>
  * <b>Sync/Async:  Synchronous</b><BR>
  * @code
    #include <DAVE3.h>
    int main (void)
    {
      status_t Status;
      DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
      Status = PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
      Status = PMSMFOCSL01_MotorStop(&PMSMFOCSL01_Handle0);
      while(1);
      return 0;
    }
  * @endcode 
  */
  status_t PMSMFOCSL01_MotorStop (const PMSMFOCSL01_HandleType* HandlePtr);
  /**
   * @brief This function calculates the speed reference value for ramp up/down
   * @param[in] HandlePtr Handle of the PMSMFOCSL01 App
   * @return void
   * <BR>
   *
   * <b>Reentrancy:  Yes</b><BR>
   * <b>Sync/Async:  Synchronous</b><BR>
   * @code
     #include <DAVE3.h>
     int main (void)
     {
       DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
       PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
       while(1);
       return 0;
     }
    //This is the PWM period match handler.
     void PMSMFOCSL01_PWMPeriodMatchInterruptHandler(&PMSMFOCSL01_Handle0)
     {
       PMSMFOCSL01_SpeedRampup(&PMSMFOCSL01_Handle0);
     }
   * @endcode
   */
  void PMSMFOCSL01_SpeedRampup(const PMSMFOCSL01_HandleType* HandlePtr);
  /**
  * @brief This function reads the potentiometer value.
  * Motor speed reference is controlled based on potentiometer value.
  * @param[in] HandlePtr Handle of the PMSMFOCSL01 App
  * @return void
  * <BR>
  *
  * <b>Reentrancy:  Yes</b><BR>
  * <b>Sync/Async:  Synchronous</b><BR>
  * @code
    #include <DAVE3.h>
    int main (void)
    {
      DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
      PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
      while(1);
      return 0;
    }
   //This is the PWM period match handler.
    void PMSMFOCSL01_PWMPeriodMatchInterruptHandler(&PMSMFOCSL01_Handle0)
    {
      PMSMFOCSL01_PotMeasurement(&PMSMFOCSL01_Handle0);
    }
  * @endcode
  */
  void PMSMFOCSL01_PotMeasurement(const PMSMFOCSL01_HandleType* HandlePtr);
  /**
  * @brief This function reads the DC link voltage value.
  * It compensates for the DC link voltage error based on this value.
  * @param[in] HandlePtr Handle of the PMSMFOCSL01 App
  * @return void
  * <BR>
  *
  * <b>Reentrancy:  Yes</b><BR>
  * <b>Sync/Async:  Synchronous</b><BR>
  * @code
    #include <DAVE3.h>
    int main (void)
    {
      DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
      PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
      while(1);
      return 0;
    }
   //This is the PWM period match handler.
    void PMSMFOCSL01_PWMPeriodMatchInterruptHandler(&PMSMFOCSL01_Handle0)
    {
      PMSMFOCSL01_VoltageCompensation(&PMSMFOCSL01_Handle0);
    }
  * @endcode
  */
  void PMSMFOCSL01_VoltageCompensation(const PMSMFOCSL01_HandleType* HandlePtr);
  /**
  * @brief This function executes Field Oriented Control loop. 
  * This in turn executes current calculation, Clarke , Park Transform, 
  * PI controller and SVM angle and amplitude calculation.
  * @param[in] HandlePtr Handle of the PMSMFOCSL01 App
  * @return void
  * <BR>
  *
  * <b>Reentrancy:  Yes</b><BR>
  * <b>Sync/Async:  Synchronous</b><BR>
  * @code
    #include <DAVE3.h>
    int main (void)
    {
      DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
      PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
      while(1);
      return 0;
    }
   //This is the PWM period match handler.
    void PMSMFOCSL01_PWMPeriodMatchInterruptHandler(&PMSMFOCSL01_Handle0)
    {
      PMSMFOCSL01_FOCCalculation(&PMSMFOCSL01_Handle0);
    }
  * @endcode
  */
  void PMSMFOCSL01_FOCCalculation(const PMSMFOCSL01_HandleType* HandlePtr);
  /**
  * @brief This function reconstructs the Phase current Ia and Ib from DC link
  * current measurement
  * @param[in] HandlePtr Handle of the PMSMFOCSL01 App
  * @return void
  * <BR>
  *
  * <b>Reentrancy:  Yes</b><BR>
  * <b>Sync/Async:  Synchronous</b><BR>
  * @code
    #include <DAVE3.h>
    int main (void)
    {
      DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
      PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
      while(1);
      return 0;
    }
   //This is the PWM period match handler.
    void PMSMFOCSL01_PWMPeriodMatchInterruptHandler(&PMSMFOCSL01_Handle0)
    {
      PMSMFOCSL01_PhaseCurrentCalc(&PMSMFOCSL01_Handle0);
    }
  * @endcode
  */
  void PMSMFOCSL01_PhaseCurrentCalc(const PMSMFOCSL01_HandleType* HandlePtr);
  /**
  * @brief This function reads the DC link current values from ADC.
  * @param[in] HandlePtr Handle of the PMSMFOCSL01 App
  * @return void
  * <BR>
  *
  * <b>Reentrancy:  Yes</b><BR>
  * <b>Sync/Async:  Synchronous</b><BR>
  * @code
    #include <DAVE3.h>
    int main (void)
    {
      DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
      PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
      while(1);
      return 0;
    }
   //This is the PWM period match handler.
    void PMSMFOCSL01_PWMPeriodMatchInterruptHandler(&PMSMFOCSL01_Handle0)
    {
      PMSMFOCSL01_ReadCurrent(&PMSMFOCSL01_Handle0);
    }
  * @endcode
  */
  void PMSMFOCSL01_ReadCurrent(const PMSMFOCSL01_HandleType* HandlePtr);
  /**
  * @brief This function calculates the flux and computes the flux angle.
  * @param[in] HandlePtr Handle of the PMSMFOCSL01 App
  * @return void
  * <BR>
  *
  * <b>Reentrancy:  Yes</b><BR>
  * <b>Sync/Async:  Synchronous</b><BR>
  * @code
    #include <DAVE3.h>
    int main (void)
    {
      DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
      PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
      while(1);
      return 0;
    }
   //This is the PWM period match handler.
    void PMSMFOCSL01_PWMPeriodMatchInterruptHandler(&PMSMFOCSL01_Handle0)
    {
      PMSMFOCSL01_FluxEstimation(&PMSMFOCSL01_Handle0);
    }
  * @endcode
  */
  void PMSMFOCSL01_FluxEstimation(const PMSMFOCSL01_HandleType* HandlePtr);
  /**
  * @brief This function will set the motor end speed reference.
  * @param[in] HandlePtr Handle of the PMSMFOCSL01 App
  * @param[in] SetSpeed Desired speed reference value in RPM
  * @return <b>status_t</b><BR>
  * DAVEApp_SUCCESS: if the function is successful<BR>
  * PMSMFOCSL01_INVALID_PARAM: If target speed is greater than 2^15 
  * <BR>
  *
  * <b>Reentrancy:  Yes</b><BR>
  * <b>Sync/Async:  Synchronous</b><BR>
  * @code
    #include <DAVE3.h>
    int main (void)
    {
      status_t Status;
      DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
      int32_t Speed=1000;
      Status = PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
      Status = PMSMFOCSL01_SetMotorEndSpeed(&PMSMFOCSL01_Handle0, Speed);
      while(1);
      return 0;
    }
  * @endcode
  */
  status_t PMSMFOCSL01_SetMotorEndSpeed(const PMSMFOCSL01_HandleType* HandlePtr,
                                              int32_t                 SetSpeed);
  /**
  * @brief This function will set the motor start speed reference.
  * @param[in] HandlePtr Handle of the PMSMFOCSL01 App
  * @param[in] SetSpeed Desired speed reference value in RPM
  * @return <b>status_t</b><BR>
  * DAVEApp_SUCCESS: if the function is successful<BR>
  * PMSMFOCSL01_INVALID_PARAM: If target speed is greater than 2^15 
  * <BR>
  *
  * <b>Reentrancy:  Yes</b><BR>
  * <b>Sync/Async:  Synchronous</b><BR>
  * @code
    #include <DAVE3.h>
    int main (void)
    {
      status_t Status;
      DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
      int32_t Speed=1000;
      Status=PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
      Status=PMSMFOCSL01_SetMotorStartSpeed(&PMSMFOCSL01_Handle0, Speed);
      while(1);
      return 0;
    }
  * @endcode
  */
  status_t PMSMFOCSL01_SetMotorStartSpeed(const PMSMFOCSL01_HandleType* HandlePtr,
                                                int32_t                 SetSpeed);
  /**
  * @brief This function gives the motor end speed reference.
  * @param[in]  HandlePtr Handle of the PMSMFOCSL01 App
  * @param[out] *GetSpeed Actual end speed reference value in RPM
  * @return <b>status_t</b><BR>
  * DAVEApp_SUCCESS: if the function is successful<BR>
  * PMSMFOCSL01_OPERATION_NOT_ALLOWED : If the function is called from
  * PMSMFOCSL01_UNINITIALIZED State.<BR>
  * <BR>
  *
  * <b>Reentrancy:  Yes</b><BR>
  * <b>Sync/Async:  Synchronous</b><BR>
  * @code
    #include <DAVE3.h>
    int main (void)
    {
      status_t Status;
      DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
      int32_t EndSpeed;
      Status=PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
      Status=PMSMFOCSL01_GetMotorEndSpeed(&PMSMFOCSL01_Handle0,&EndSpeed);
      while(1);
      return 0;
    }
  * @endcode
  */
  status_t PMSMFOCSL01_GetMotorEndSpeed(const PMSMFOCSL01_HandleType* HandlePtr,
                                              int32_t*                GetSpeed);
  /**
  * @brief This function get the motor start speed reference.
  * @param[in]  HandlePtr Handle of the PMSMFOCSL01 App
  * @param[out] *GetSpeed Actual start speed reference value in RPM
  * @return <b>status_t</b><BR>
  * DAVEApp_SUCCESS: if the function is successful<BR>
  * PMSMFOCSL01_OPERATION_NOT_ALLOWED : If the function is called from
  * PMSMFOCSL01_UNINITIALIZED State.<BR>
  * <BR>
  *
  * <b>Reentrancy:  Yes</b><BR>
  * <b>Sync/Async:  Synchronous</b><BR>
  * @code
    #include <DAVE3.h>
    int main (void)
    {
      status_t Status;
      DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
      int32_t StartSpeed;
      Status=PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
      Status=PMSMFOCSL01_GetMotorEndSpeed(&PMSMFOCSL01_Handle0,&StartSpeed);
      while(1);
      return 0;
    }
  * @endcode
  */
  status_t PMSMFOCSL01_GetMotorStartSpeed
  (const PMSMFOCSL01_HandleType* HandlePtr,
  int32_t*                       GetSpeed);
  /**
  * @brief This function gives the motor speed reference.
  * @param[in]  HandlePtr Handle of the PMSMFOCSL01 App
  * @param[out] *SpeedPtr Actual motor speed value in RPM
  * @return <b>status_t</b><BR>
  * DAVEApp_SUCCESS: if the function is successful<BR>
  * PMSMFOCSL01_OPERATION_NOT_ALLOWED : If the function is called from
  * PMSMFOCSL01_UNINITIALIZED State.<BR>
  * <BR>
  *
  * <b>Reentrancy:  Yes</b><BR>
  * <b>Sync/Async:  Synchronous</b><BR>
  * @code
    #include <DAVE3.h>
    int main (void)
    {
      status_t Status;
      DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
      int32_t Speed;
      Status=PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
      Status=PMSMFOCSL01_GetMotSpeed(&PMSMFOCSL01_Handle0,&Speed);
      while(1);
      return 0;
    }
  * @endcode
  */
  status_t PMSMFOCSL01_GetMotSpeed(const PMSMFOCSL01_HandleType* HandlePtr,
                                         int32_t*                SpeedPtr);
  /**
  * @brief This function gives the current motor status.
  * @param[in]  HandlePtr Handle of the PMSMFOCSL01 App
  * @param[out] *StatusPtr This is motor status variable
  * @return <b>status_t</b><BR>
  * DAVEApp_SUCCESS: if the function is successful<BR>
  * PMSMFOCSL01_OPERATION_NOT_ALLOWED : If the function is called from
  * PMSMFOCSL01_UNINITIALIZED State.<BR>
  * <BR>
  *
  * <b>Reentrancy:  Yes</b><BR>
  * <b>Sync/Async:  Synchronous</b><BR>
  * @code
    #include <DAVE3.h>
    int main (void)
    {
      status_t Status;
      DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
      uint16_t MotorStatus;
      Status=PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
      Status=PMSMFOCSL01_GetMotStatus(&PMSMFOCSL01_Handle0, &MotorStatus);
      while(1);
      return 0;
    }
  * @endcode
  */
  status_t PMSMFOCSL01_GetMotStatus(const PMSMFOCSL01_HandleType* HandlePtr,
                                          uint16_t*               StatusPtr);
  /**
  * @brief This function gives the slew rate of the motor.
  * @param[in]  HandlePtr Handle of the PMSMFOCSL01 App
  * @param[out] *SlewRatePtr This is motor slew rate variable
  * @return <b>status_t</b><BR>
  * DAVEApp_SUCCESS: if the function is successful<BR>
  * PMSMFOCSL01_OPERATION_NOT_ALLOWED : If the function is called from
  * PMSMFOCSL01_UNINITIALIZED State.<BR>
  * <BR>
  *
  * <b>Reentrancy:  Yes</b><BR>
  * <b>Sync/Async:  Synchronous</b><BR>
  * @code
    #include <DAVE3.h>
    int main (void)
    {
      status_t Status;
      DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
      uint32_t SlewRate;
      Status=PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
      Status=PMSMFOCSL01_GetSlewRate(&PMSMFOCSL01_Handle0, &SlewRate);
      while(1);
      return 0;
    }
  * @endcode
  */
  status_t PMSMFOCSL01_GetSlewRate(const PMSMFOCSL01_HandleType* HandlePtr,
                                         uint32_t*               SlewRatePtr);
  /**
  * @brief This function gives the motor direction.
  * @param[in]  HandlePtr Handle of the PMSMFOCSL01 App
  * @param[out] *DirPtr This is motor direction variable
  * @return <b>status_t</b><BR>
  * DAVEApp_SUCCESS: if the function is successful<BR>
  * PMSMFOCSL01_OPERATION_NOT_ALLOWED : If the function is called from
  * PMSMFOCSL01_UNINITIALIZED State.<BR>
  * <BR>
  *
  * <b>Reentrancy:  Yes</b><BR>
  * <b>Sync/Async:  Synchronous</b><BR>
  * @code
    #include <DAVE3.h>
    int main (void)
    {
      status_t Status;
      DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
      int32_t DirPtr;
      Status=PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
      Status=PMSMFOCSL01_GetMotDirection(&PMSMFOCSL01_Handle0,&DirPtr);
      while(1);
      return 0;
    }
  * @endcode
  */
  status_t PMSMFOCSL01_GetMotDirection(const PMSMFOCSL01_HandleType* HandlePtr,
                                             int32_t*                DirPtr);
  /**
  * @brief This function sets the motor direction.
  * @param[in]  HandlePtr Handle of the PMSMFOCSL01 App
  * @param[in] MotDirVal This is motor direction variable,this value is either
  * 1 or -1. \n
  * 1 ->Forward Direction \n
  * -1->Reverse Direction
  * @return <b>status_t</b><BR>
  * DAVEApp_SUCCESS: if the function is successful<BR>
  * PMSMFOCSL01_OPERATION_NOT_ALLOWED : If the function is called from
  * PMSMFOCSL01_UNINITIALIZED State.<BR>
  * <BR>
  *
  * <b>Reentrancy:  Yes</b><BR>
  * <b>Sync/Async:  Synchronous</b><BR>
  * @code
    #include <DAVE3.h>
    int main (void)
    {
      status_t Status;
      DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
      Status=PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
      Status=PMSMFOCSL01_SetMotDirection(&PMSMFOCSL01_Handle0,1);
      while(1);
      return 0;
    }
  * @endcode
  */
  status_t PMSMFOCSL01_SetMotDirection(const PMSMFOCSL01_HandleType* HandlePtr,
                                             int32_t                 MotDirVal);
  /**
  * @brief This function sets the motor slew rate.
  * @param[in]  HandlePtr Handle of the PMSMFOCSL01 App
  * @param[in] SlewRateVal  Desired slew rate of the motor in RPM/s
  * @return <b>status_t</b><BR>
  * DAVEApp_SUCCESS: if the function is successful<BR>
  * PMSMFOCSL01_OPERATION_NOT_ALLOWED : If the function is called from
  * PMSMFOCSL01_UNINITIALIZED State.<BR>
  * <BR>
  *
  * <b>Reentrancy:  Yes</b><BR>
  * <b>Sync/Async:  Synchronous</b><BR>
  * @code
    #include <DAVE3.h>
    int main (void)
    {
      status_t Status;
      DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
      Status=PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
      Status=PMSMFOCSL01_SetSlewRate(&PMSMFOCSL01_Handle0,500);
      while(1);
      return 0;
    }
  * @endcode
  */
  status_t PMSMFOCSL01_SetSlewRate(const PMSMFOCSL01_HandleType* HandlePtr,
                                         uint32_t                SlewRateVal);
  /**
  * @brief This function sets the speed proportional gain.
  * @param[in] HandlePtr Handle of the PMSMFOCSL01 App
  * @param[in] Kp  Desired speed Kp value of the motor
  * @return <b>status_t</b><BR>
  * DAVEApp_SUCCESS: if the function is successful<BR>
  * PMSMFOCSL01_INVALID_PARAM: If Kp is greater than 2^15
  * 
  * <BR>
  *
  * <b>Reentrancy:  Yes</b><BR>
  * <b>Sync/Async:  Synchronous</b><BR>
  * @code
    #include <DAVE3.h>
    int main (void)
    {
      status_t Status;
      DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
      Status=PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
      Status=PMSMFOCSL01_SetSpeedProportionalGain(&PMSMFOCSL01_Handle0,500);
      while(1);
      return 0;
    }
  * @endcode
  */
  status_t PMSMFOCSL01_SetSpeedProportionalGain
  (const PMSMFOCSL01_HandleType* HandlePtr,
   uint16_t                      Kp);
  /**
  * @brief This function sets the speed integral gain.
  * @param[in] HandlePtr Handle of the PMSMFOCSL01 App
  * @param[in] Ki  Desired speed Ki value of the motor
  * @return <b>status_t</b><BR>
  * DAVEApp_SUCCESS: if the function is successful<BR>
  * PMSMFOCSL01_INVALID_PARAM: If Ki is greater than 2^15
  * <BR>
  *
  * <b>Reentrancy:  Yes</b><BR>
  * <b>Sync/Async:  Synchronous</b><BR>
  * @code
    #include <DAVE3.h>
    int main (void)
    {
      status_t Status;
      DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
      Status=PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
      Status=PMSMFOCSL01_SetSpeedIntegralGain(&PMSMFOCSL01_Handle0, 10);
      while(1);
      return 0;
    }
  * @endcode
  */
  status_t PMSMFOCSL01_SetSpeedIntegralGain
  (const PMSMFOCSL01_HandleType* HandlePtr,
         uint16_t                Ki);
  /**
  * @brief This function sets the quadrature axis current component(Iq) 
  * proportional gain of motor.
  * @param[in] HandlePtr Handle of the PMSMFOCSL01 App
  * @param[in] Kp  Quadrature Current Kp value of the motor
  * @return <b>status_t</b><BR>
  * DAVEApp_SUCCESS: if the function is successful<BR>
  * PMSMFOCSL01_INVALID_PARAM: If Kp is greater than 2^15
  * <BR>
  *
  * <b>Reentrancy:  Yes</b><BR>
  * <b>Sync/Async:  Synchronous</b><BR>
  * @code
    #include <DAVE3.h>
    int main (void)
    {
      status_t Status;
      DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
      Status=PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
      Status=PMSMFOCSL01_SetIqProportionalGain(&PMSMFOCSL01_Handle0,500);
      while(1);
      return 0;
    }
  * @endcode
  */
  status_t PMSMFOCSL01_SetIqProportionalGain
  (const PMSMFOCSL01_HandleType* HandlePtr,
   uint16_t                      Kp);
  /**
  * @brief This function sets the quadrature axis current component(Iq) integral
  * gain of motor.
  * @param[in] HandlePtr Handle of the PMSMFOCSL01 App
  * @param[in] Ki  Quadrature Current Ki value of the motor
  * @return <b>status_t</b><BR>
  * DAVEApp_SUCCESS: if the function is successful<BR>
  * PMSMFOCSL01_INVALID_PARAM: If Ki is greater than 2^15
  * <BR>
  *
  * <b>Reentrancy:  Yes</b><BR>
  * <b>Sync/Async:  Synchronous</b><BR>
  * @code
    #include <DAVE3.h>
    int main (void)
    {
      status_t Status;
      DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
      Status=PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
      Status=PMSMFOCSL01_SetIqIntegralGain(&PMSMFOCSL01_Handle0,10);
      while(1);
      return 0;
    }
  * @endcode
  */
  status_t PMSMFOCSL01_SetIqIntegralGain(const PMSMFOCSL01_HandleType* HandlePtr,
                                               uint16_t                Ki);
  /**
  * @brief This function sets the direct axis current component(Id) proportional
  * gain of motor.
  * @param[in] HandlePtr Handle of the PMSMFOCSL01 App
  * @param[in] Kp  Direct Current Kp value of the motor
  * @return <b>status_t</b><BR>
  * DAVEApp_SUCCESS: if the function is successful<BR>
  * PMSMFOCSL01_INVALID_PARAM: If Kp is greater than 2^15
  * <BR>
  *
  * <b>Reentrancy:  Yes</b><BR>
  * <b>Sync/Async:  Synchronous</b><BR>
  * @code
    #include <DAVE3.h>
    int main (void)
    {
      status_t Status;
      DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
      Status=PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
      Status=PMSMFOCSL01_SetIdProportionalGain(&PMSMFOCSL01_Handle0,500);
      while(1);
      return 0;
    }
  * @endcode
  */
  status_t PMSMFOCSL01_SetIdProportionalGain
  (const PMSMFOCSL01_HandleType* HandlePtr,
   uint16_t                      Kp);
  /**
  * @brief This function sets the direct axis current component(Id) integral
  * gain of motor.
  * @param[in] HandlePtr Handle of the PMSMFOCSL01 App
  * @param[in] Ki  Direct Current Ki value of the motor
  * @return <b>status_t</b><BR>
  * DAVEApp_SUCCESS: if the function is successful<BR>
  * PMSMFOCSL01_INVALID_PARAM: If Ki is greater than 2^15
  * <BR>
  *
  * <b>Reentrancy:  Yes</b><BR>
  * <b>Sync/Async:  Synchronous</b><BR>
  * @code
    #include <DAVE3.h>
    int main (void)
    {
      status_t Status;
      DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
      Status=PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
      Status=PMSMFOCSL01_SetIdIntegralGain(&PMSMFOCSL01_Handle0,10);
      while(1);
      return 0;
    }
  * @endcode
  */
  status_t PMSMFOCSL01_SetIdIntegralGain(const PMSMFOCSL01_HandleType* HandlePtr,
                                               uint16_t                Ki);
  /**
  * @brief This function gets the speed proportional gain.
  * @param[in] HandlePtr Handle of the PMSMFOCSL01 App
  * @param[out] *Kp  speed Kp value of the motor
  * @return <b>status_t</b><BR>
  * DAVEApp_SUCCESS: if the function is successful<BR>
  * PMSMFOCSL01_OPERATION_NOT_ALLOWED : If the function is called from
  * PMSMFOCSL01_UNINITIALIZED State.<BR>
  * 
  * <BR>
  *
  * <b>Reentrancy:  Yes</b><BR>
  * <b>Sync/Async:  Synchronous</b><BR>
  * @code
    #include <DAVE3.h>
    int main (void)
    {
      status_t Status;
      uint16_t Kp;
      DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
      Status=PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
      Status=PMSMFOCSL01_GetSpeedProportionalGain(&PMSMFOCSL01_Handle0,&Kp);
      while(1);
      return 0;
    }
  * @endcode
  */
  status_t PMSMFOCSL01_GetSpeedProportionalGain
  (const PMSMFOCSL01_HandleType* HandlePtr,
         uint16_t*               Kp);
  /**
  * @brief This function gets the speed integral gain.
  * @param[in] HandlePtr Handle of the PMSMFOCSL01 App
  * @param[out] *Ki  speed Ki value of the motor
  * @return <b>status_t</b><BR>
  * DAVEApp_SUCCESS: if the function is successful<BR>
  * PMSMFOCSL01_OPERATION_NOT_ALLOWED : If the function is called from
  * PMSMFOCSL01_UNINITIALIZED State.<BR>
  * <BR>
  *
  * <b>Reentrancy:  Yes</b><BR>
  * <b>Sync/Async:  Synchronous</b><BR>
  * @code
    #include <DAVE3.h>
    int main (void)
    {
      status_t Status;
      uint16_t Ki;
      DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
      Status=PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
      Status=PMSMFOCSL01_GetSpeedIntegralGain(&PMSMFOCSL01_Handle0,&Ki);
      while(1);
      return 0;
    }
  * @endcode
  */
  status_t PMSMFOCSL01_GetSpeedIntegralGain
  (const PMSMFOCSL01_HandleType* HandlePtr,
         uint16_t*               Ki);
  /**
  * @brief This function gets the quadrature axis current component(Iq) 
  *  proportional gain of motor.
  * @param[in] HandlePtr Handle of the PMSMFOCSL01 App
  * @param[out] *Kp  Quadrature Current Kp value of the motor
  * @return <b>status_t</b><BR>
  * DAVEApp_SUCCESS: if the function is successful<BR>
  * PMSMFOCSL01_OPERATION_NOT_ALLOWED : If the function is called from
  * PMSMFOCSL01_UNINITIALIZED State.<BR>
  * <BR>
  *
  * <b>Reentrancy:  Yes</b><BR>
  * <b>Sync/Async:  Synchronous</b><BR>
  * @code
    #include <DAVE3.h>
    int main (void)
    {
      status_t Status;
      uint16_t Kp;
      DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
      Status=PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
      Status=PMSMFOCSL01_GetIqProportionalGain(&PMSMFOCSL01_Handle0,&Kp);
      while(1);
      return 0;
    }
  * @endcode
  */
  status_t PMSMFOCSL01_GetIqProportionalGain
  (const PMSMFOCSL01_HandleType* HandlePtr,
         uint16_t*               Kp);
  /**
  * @brief This function gets the quadrature axis current component(Iq) integral
  *  gain of motor.
  * @param[in] HandlePtr Handle of the PMSMFOCSL01 App
  * @param[out] *Ki  Quadrature Current Ki value of the motor
  * @return <b>status_t</b><BR>
  * DAVEApp_SUCCESS: if the function is successful<BR>
  * PMSMFOCSL01_OPERATION_NOT_ALLOWED : If the function is called from
  * PMSMFOCSL01_UNINITIALIZED State.<BR>
  * <BR>
  *
  * <b>Reentrancy:  Yes</b><BR>
  * <b>Sync/Async:  Synchronous</b><BR>
  * @code
    #include <DAVE3.h>
    int main (void)
    {
      status_t Status;
      uint16_t Ki;
      DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
      Status=PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
      Status=PMSMFOCSL01_GetIqIntegralGain(&PMSMFOCSL01_Handle0,&Ki);
      while(1);
      return 0;
    }
  * @endcode
  */
  status_t PMSMFOCSL01_GetIqIntegralGain(const PMSMFOCSL01_HandleType* HandlePtr,
                                               uint16_t*               Ki);
  /**
  * @brief This function gets the direct axis current component(Id) proportional 
  *  gain of motor.
  * @param[in] HandlePtr Handle of the PMSMFOCSL01 App
  * @param[out] *Kp  Direct Current Kp value of the motor
  * @return <b>status_t</b><BR>
  * DAVEApp_SUCCESS: if the function is successful<BR>
  * PMSMFOCSL01_OPERATION_NOT_ALLOWED : If the function is called from
  * PMSMFOCSL01_UNINITIALIZED State.<BR>
  * <BR>
  *
  * <b>Reentrancy:  Yes</b><BR>
  * <b>Sync/Async:  Synchronous</b><BR>
  * @code
    #include <DAVE3.h>
    int main (void)
    {
      status_t Status;
      uint16_t Kp;
      DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
      Status=PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
      Status=PMSMFOCSL01_GetIdProportionalGain(&PMSMFOCSL01_Handle0,&Kp);
      while(1);
      return 0;
    }
  * @endcode
  */
  status_t PMSMFOCSL01_GetIdProportionalGain
  (const PMSMFOCSL01_HandleType* HandlePtr,
         uint16_t*               Kp);
  /**
  * @brief This function gets the direct axis current component(Id) integral
  * gain of motor.
  * @param[in] HandlePtr Handle of the PMSMFOCSL01 App
  * @param[out] *Ki  Direct Current Ki value of the motor
  * @return <b>status_t</b><BR>
  * DAVEApp_SUCCESS: if the function is successful<BR>
  * PMSMFOCSL01_OPERATION_NOT_ALLOWED : If the function is called from
  * PMSMFOCSL01_UNINITIALIZED State.<BR>
  * <BR>
  *
  * <b>Reentrancy:  Yes</b><BR>
  * <b>Sync/Async:  Synchronous</b><BR>
  * @code
    #include <DAVE3.h>
    int main (void)
    {
      status_t Status;
      uint16_t Ki;
      DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
      Status=PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
      Status=PMSMFOCSL01_GetIdIntegralGain(&PMSMFOCSL01_Handle0,&Ki);
      while(1);
      return 0;
    }
  * @endcode
  */
  status_t PMSMFOCSL01_GetIdIntegralGain(const PMSMFOCSL01_HandleType* HandlePtr,
                                               uint16_t*               Ki);
  /**
  * @brief This function will set the motor threshold speed reference.
  * At this speed, motor will switch from V/F open loop to FOC closed loop.
  * @param[in] HandlePtr Handle of the PMSMFOCSL01 App
  * @param[in] SetSpeed Desired threshold speed reference value in RPM
  * @return <b>status_t</b><BR>
  * DAVEApp_SUCCESS: if the function is successful<BR>
  * PMSMFOCSL01_INVALID_PARAM: If SetSpeed is greater than 2^15 <BR>
  * <BR>
  *
  * <b>Reentrancy:  Yes</b><BR>
  * <b>Sync/Async:  Synchronous</b><BR>
  * @code
    #include <DAVE3.h>
    int main (void)
    {
      status_t Status;
      DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
      int32_t Speed=1000;
      Status = PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
      Status = PMSMFOCSL01_SetMotorSpeedThreshold(&PMSMFOCSL01_Handle0,2500);
      while(1);
      return 0;
    }
  * @endcode
  */
  status_t PMSMFOCSL01_SetMotorSpeedThreshold
  (const PMSMFOCSL01_HandleType* HandlePtr,
         int32_t                 SetSpeed);
  /**
  * @brief This function will get the motor threshold speed reference.
  * @param[in]  HandlePtr Handle of the PMSMFOCSL01 App
  * @param[out] *GetSpeed Actual threshold speed value in RPM
  * @return <b>status_t</b><BR>
  * DAVEApp_SUCCESS: if the function is successful<BR>
  * PMSMFOCSL01_OPERATION_NOT_ALLOWED : If the function is called from
  * PMSMFOCSL01_UNINITIALIZED State.<BR>
  * <BR>
  *
  * <b>Reentrancy:  Yes</b><BR>
  * <b>Sync/Async:  Synchronous</b><BR>
  * @code
    #include <DAVE3.h>
    int main (void)
    {
      status_t Status;
      DAVE_Init();   //PMSMFOCSL01_Init is called within DAVE_Init
      int32_t Speed;
      Status=PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
      Status=PMSMFOCSL01_GetMotorSpeedThreshold(&PMSMFOCSL01_Handle0,&Speed);
      while(1);
      return 0;
    }
  * @endcode
  */
  status_t PMSMFOCSL01_GetMotorSpeedThreshold
  (const PMSMFOCSL01_HandleType* HandlePtr,
         int32_t*                GetSpeed);
  /**
  * @}
  */
  
/*******************************************************************************
** STRUCTURES:
*******************************************************************************/ 
  
#include "PMSMFOCSL01_Conf.h"
#include "PMSMFOCSL01_Extern.h"  
  
/* Support for C++ codebase */
#ifdef __cplusplus
 }
#endif  
#endif /* PMSMFOCSL01_H_ */

 
