/*******************************************************************************
**  DAVE App Name : DBG002       App Version: 1.0.22               
**  This file is generated by DAVE, User modification to this file will be    **
**  overwritten at the next code generation.                                  **
*******************************************************************************/


/*******************************************************************************
 Copyright (c) 2011, Infineon Technologies AG                                 **
 All rights reserved.                                                         **
                                                                              **
 Redistribution and use in source and binary forms, with or without           **
 modification,are permitted provided that the following conditions are met:   **
                                                                              **
 *Redistributions of source code must retain the above copyright notice,      **
 this list of conditions and the following disclaimer.                        **
 *Redistributions in binary form must reproduce the above copyright notice,   **
 this list of conditions and the following disclaimer in the documentation    **
 and/or other materials provided with the distribution.                       **
 *Neither the name of the copyright holders nor the names of its contributors **
 may be used to endorse or promote products derived from this software without** 
 specific prior written permission.                                           **
                                                                              **
 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"  **
 AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE    **
 IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE   **
 ARE  DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE   **
 LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR         **
 CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF         **
 SUBSTITUTE GOODS OR  SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS    **
 INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN      **
 CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)       **
 ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE   **
 POSSIBILITY OF SUCH DAMAGE.                                                  **
                                                                              **
 To improve the quality of the software, users are encouraged to share        **
 modifications, enhancements or bug fixes with Infineon Technologies AG       **
 dave@infineon.com).                                                          **
                                                                              **
********************************************************************************
**                                                                            **
**                                                                            **
** PLATFORM : Infineon XMC4000 Series                                         **
**                                                                            **
** COMPILER : Compiler Independent                                            **
**                                                                            **
** AUTHOR : App Developer                                                     **
**                                                                            **
** MAY BE CHANGED BY USER [yes/no]: Yes                                       **
**                                                                            **
** MODIFICATION DATE : Dec 12, 2012                                           **
**                                                                            **
*******************************************************************************/

/*******************************************************************************
**                       Author(s) Identity                                   **
********************************************************************************
**                                                                            **
** Initials    Name                                                           **
** ---------------------------------------------------------------------------**
** NPJ          App Developer                                                  **
*******************************************************************************/
/**
 * @file DBG002_PhyInterface.c
 *
 * @App Version DBG002 <1.0.22>
 * @brief Implementation of physical Interface Abstraction functions
 *
 */


/*******************************************************************************
 **                         INCLUDE FILES                                     **
 ******************************************************************************/
/* Inclusion of DebugLog Private Definitions */
#include <DAVE3.h>
/* Inclusion of DebugLog Private Definitions */
#include "../../inc/DBG002/DBG002_Private.h"
#include "../../inc/DBG002/DBG002_UART.h"

/*******************************************************************************
**                      Global Variable Definitions                           **
*******************************************************************************/
extern DBG002_LoggingMessageFormatType CircularBufElementCh1[DBG002_CIRCULAR_BUFF_SIZE_CH1];

/* Buffer to store Received message */
uint8_t UART_RxBuffer[16];
/* Buffer to store Received message */
DBG002_CommandFromHostType CmdBuffer;

/* Ack status flag */
volatile uint8_t SendAckStatus = (uint8_t)FALSE;
/* Nack status flag */
volatile uint8_t SendNackStatus = (uint8_t)FALSE;
/* Uart trigger status */
volatile uint8_t isComingUartTxTrigger = (uint8_t)FALSE;


/***************************************************************************
 *					Macro Function
 *
 ***************************************************************************/
 
 /*  USIC FIFO standard transmit buffer interrupt handler */
#define DBG002_TransmitBufferCallback IRQ_Hdlr_9

/*  USIC FIFO standard receive buffer interrupt handler */
#define DBG002_ReceiveBufferCallback IRQ_Hdlr_10

/* Macro function to check is current reception is going on
 * uart channel*/
#define DBG002_GetRxTransferStatus(Ch) RD_REG(Ch->PSR_ASCMode,USIC_CH_PSR_ASCMode_BUSY_Msk, \
		                                           USIC_CH_PSR_ASCMode_BUSY_Pos)

/* Trigger Uart Transmit buffer interrupt */       
static void DBG002_TriggerUartTxIntrpt(void) {
    uint8_t SRno;
    SRno = (((uint32_t)DBG002_UARTHandle0.UartRegs->TBCTR &
         USIC_CH_TBCTR_STBINP_Msk) >> USIC_CH_TBCTR_STBINP_Pos);
    DBG002_UARTHandle0.UartRegs->FMR |= ((uint32_t)(0x01U <<
                          (USIC_CH_FMR_SIO0_Pos + SRno)));
}

/* Fletcher8 checksum */
uint8_t DBG002_lFletcher8(uint8_t *data, uint8_t len) {
    uint8_t sum1 = 0xf, sum2 = 0xf;

    while (len) {
        unsigned tlen = len > 360 ? 360 : len;
        len -= tlen;
        do {
                sum1 += *data++;
                sum2 += sum1;
                tlen -= sizeof( uint8_t );
        } while (tlen);
        sum1 = (sum1 & 0xf) + (sum1 >> 4);
        sum2 = (sum2 & 0xf) + (sum2 >> 4);
    }
    /* Second reduction step to reduce sums to 4 bits */
    sum1 = (sum1 & 0xf) + (sum1 >> 4);
    sum2 = (sum2 & 0xf) + (sum2 >> 4);
    return sum2 << 4 | sum1;
}

/* Function to check if received checksum and calculated checksum are same */
uint8_t DBG002_lIsCheckSumOk(void) {
    uint8_t calc_cs = 0U;
	uint8_t rec_cs = 0U;
	uint8_t status = 0U;

	calc_cs = DBG002_lFletcher8(UART_RxBuffer, 15U);
	rec_cs = UART_RxBuffer[15];

	if (calc_cs == rec_cs)
        status = (uint8_t)TRUE;
	else
		status = (uint8_t)FALSE;
	return status;
}

/* Fifo receive buffer call back */
void DBG002_ReceiveBufferCallback(void)
{
    uint8_t i;
    uint8_t *UART_RxBufferPtr = (uint8_t *)(&UART_RxBuffer[0]);
    static uint8_t *CmdBufferPtr = (uint8_t *)(&CmdBuffer);
    
    // Read command
    for (i = 16; i != 0; i--) {
        *(UART_RxBufferPtr++) = (uint8_t)(DBG002_UARTHandle0.UartRegs->OUTR);
    }

	if (DBG002_lIsCheckSumOk()) {
		SendAckStatus = (uint8_t)TRUE;
		if (isComingUartTxTrigger == FALSE) {
			DBG002_TriggerUartTxIntrpt();
		}

		UART_RxBufferPtr -= 15;
	    for (i = 14; i != 0; i--) {
    	    (*CmdBufferPtr++) = *(UART_RxBufferPtr++);
    	}

		if ((UART_RxBuffer[0] & 0x80) == 0) { // last fragment
			CmdBufferPtr = (uint8_t *)(&CmdBuffer);
			DBG002_lProcessCommand(&CmdBuffer);
		}
	}
	else {
		CmdBufferPtr = (uint8_t *)(&CmdBuffer); // We need to start with the complete sequence again
		SendNackStatus = (uint8_t)TRUE;
		if(isComingUartTxTrigger == FALSE) {
			DBG002_TriggerUartTxIntrpt();
		}
	}
}

/* Fifo transmit buffer call back */
void DBG002_TransmitBufferCallback(void)
{
  typedef enum{
		   STOP=0,
		   STD_MSG_TRANSMIT,
		   DATA_STREAMING_TRANSMIT,
		   COUNTER2_TRANSMIT,
		   NACK_ACK_TRANSMIT,
		   HEADER_STREAMING_TRANSMIT
	  } t_TxStatus;

  /* Buffer to store ACK frame */
  static const uint8_t AckFrameBuffer[10] = {0xAA,0xAA,0xFF,0x00,0x00,0x00,0x00,0x00,0xFE,0x00};
  /* Buffer to store NACK frame */
  static const uint8_t NackFrameBuffer[10] = {0xAA,0xAA,0xFF,0x00,0x00,0x00,0x00,0x00,0xFD,0x00};

  /* Transmit status */
  static t_TxStatus s_CurrentTxStatus;
  /* Next byte to be sent static */
  static uint8_t * s_ptrNextByte=NULL;
  /* Last byte to be sent  static */
  static uint8_t * s_ptrEndByte=NULL;
  /* Transmit message buffer static*/
  static DBG002_LoggingMessageFormatType* s_UARTTxMessage=NULL;

  /* circular buffer index for reading the next message */
  static uint8_t circularBufferReadIndex = 0;

  /* Next byte to be sent */
  register uint8_t * ptrNextByte=s_ptrNextByte;
  /* Last byte to be sent */
  register uint8_t * ptrEndNextByte=s_ptrEndByte;
  /* Transmit message buffer*/
  register DBG002_LoggingMessageFormatType* UARTTxMessage= s_UARTTxMessage;
  /* Transmit status */
  register t_TxStatus CurrentTxStatus=s_CurrentTxStatus;

  /* Holds status of FIFO */
  BOOLType isTxFifoFull = FALSE;

  /* Check if any data is remaining for transmission */
  if(CurrentTxStatus == STOP)
  {
	/* Check if any ACK frame has to be transmitted */
    if(SendAckStatus == TRUE)
    {
    	/*Change the buffer to transmit to Ack frame buffer */
    	UARTTxMessage = (DBG002_LoggingMessageFormatType*)&AckFrameBuffer[0];
    	ptrNextByte=(uint8_t *)UARTTxMessage;
    	ptrEndNextByte = ptrNextByte + sizeof(AckFrameBuffer);
    	/* Change the current transmit status to ongoing */
        CurrentTxStatus = NACK_ACK_TRANSMIT;
        SendAckStatus = (uint8_t)FALSE;
        /* Flag to check trigger status */
    }
    else if(SendNackStatus == TRUE)
    {
    	/*Change the buffer to transmit to Ack frame buffer */
    	UARTTxMessage = (DBG002_LoggingMessageFormatType*)&NackFrameBuffer[0];
    	ptrNextByte=(uint8_t *)UARTTxMessage;
    	ptrEndNextByte = ptrNextByte + sizeof(NackFrameBuffer);
    	/* Change the current transmit status to ongoing */
        CurrentTxStatus = NACK_ACK_TRANSMIT;
        SendNackStatus = (uint8_t)FALSE;
        /* Flag to check trigger status */
        
        /*
         * Flush the FIFO if NACK is being
         * sent to the host.
         */
         USIC_FlushRxFIFO(DBG002_UARTHandle0.UartRegs);
    }
	/* Check if valid message is available in circular buffer  */
    else if(CircularBufElementCh1[circularBufferReadIndex].isNew == TRUE)
    {
      /* Put the start address of current circular buffer element */
      UARTTxMessage = &(CircularBufElementCh1[circularBufferReadIndex]);
      ptrNextByte=(uint8_t *)UARTTxMessage;


      if(UARTTxMessage->StreamBufPtr != NULL)
      {
    	  CurrentTxStatus = HEADER_STREAMING_TRANSMIT;
    	  /* Only the header shall be transmitted */
    	  ptrEndNextByte = (uint8_t *)(&(UARTTxMessage->MessageLen)) +1 ;
      } else {
    	  CurrentTxStatus = STD_MSG_TRANSMIT;
    	  /* Transmit everything except the Counter2 */
    	  ptrEndNextByte =  (uint8_t *) &(UARTTxMessage->Message[UARTTxMessage->MessageLen-1]) + 1;
      }
      /* Point to next circular buffer element*/
      circularBufferReadIndex++;
      circularBufferReadIndex =circularBufferReadIndex % DBG002_CIRCULAR_BUFF_SIZE_CH1;
    }
    else
    {
      ptrNextByte=NULL;
    }
  }
  if (CurrentTxStatus==NACK_ACK_TRANSMIT) 
  {
    /* Write to FIFO till Fifo is full */
    while(1)
    {
      /* Check if all the message is transmitted */
	  if(ptrNextByte == ptrEndNextByte)
	  {
        isTxFifoFull = FALSE;
	    CurrentTxStatus = STOP;
	    break;
	  } 
	  else  if (USIC_IsTxFIFOfull(DBG002_UARTHandle0.UartRegs) != 1)
      {
	    DBG002_UARTWriteData(DBG002_UARTHandle0,*ptrNextByte);
	    ptrNextByte++;
	  } 
	  else
      {
        isTxFifoFull = TRUE;
	    break;
      }
    }
  } 
  else if (CurrentTxStatus==STD_MSG_TRANSMIT) 
  {
    /* Write to FIFO till Fifo is full */
	while(1)
	{
	  /* Check if all the message is transmitted */
	  if(ptrNextByte == ptrEndNextByte)
      {
        isTxFifoFull = FALSE;
	    CurrentTxStatus = COUNTER2_TRANSMIT;
	    break;
	  } else  if (USIC_IsTxFIFOfull(DBG002_UARTHandle0.UartRegs) != 1)
	  {
	    DBG002_UARTWriteData(DBG002_UARTHandle0,*ptrNextByte);
	    ptrNextByte++;

	  } 
	  else
	  {
        isTxFifoFull = TRUE;
	    break;
	  }
	}
  }
  else if (CurrentTxStatus==HEADER_STREAMING_TRANSMIT) 
  {
    /* Write to FIFO till Fifo is full */
	while(1)
    {
	  /* Check if all the message is transmitted */
	  if(ptrNextByte == ptrEndNextByte)
      {
        isTxFifoFull = FALSE;
	    ptrNextByte=&(UARTTxMessage->StreamBufPtr->Buffer[0]);
	  	ptrEndNextByte= &(UARTTxMessage->StreamBufPtr->Buffer[UARTTxMessage->MessageLen]);
	  	CurrentTxStatus = DATA_STREAMING_TRANSMIT;
	  	break;
	  } 
	  else  if (USIC_IsTxFIFOfull(DBG002_UARTHandle0.UartRegs) != 1U)
	  {
	    DBG002_UARTWriteData(DBG002_UARTHandle0,*ptrNextByte);
	    ptrNextByte++;
      }
	  else
      {
        isTxFifoFull = TRUE;
    	break;
      }
    }
  }
  if (CurrentTxStatus==DATA_STREAMING_TRANSMIT)
  {
    /* Write to FIFO till Fifo is full */
  	while(1)
	{
	  /* Check if all the message is transmitted */
  	  if(ptrNextByte == ptrEndNextByte)
	  {
        isTxFifoFull = FALSE;
  	    CurrentTxStatus = COUNTER2_TRANSMIT;
  	    UARTTxMessage->StreamBufPtr->BufferStatus = DBG002_BUF_READY;
  	    break;
  	  } 
  	  else  if (USIC_IsTxFIFOfull(DBG002_UARTHandle0.UartRegs) != 1U)
	  {
  	    DBG002_UARTWriteData(DBG002_UARTHandle0,*ptrNextByte);
  	    ptrNextByte++;
  	  }
  	  else
  	  {
          isTxFifoFull = TRUE;
  	      break;
  	  }
    }
  }
  if (CurrentTxStatus==COUNTER2_TRANSMIT) 
  {
	  if (USIC_IsTxFIFOfull(DBG002_UARTHandle0.UartRegs) != 1U)
	  {
          isTxFifoFull = FALSE;
		  /*Transmit the second counter value */
		  DBG002_UARTWriteData(DBG002_UARTHandle0,UARTTxMessage->Counter2);
	      /* Change the circular buffer status to false state*/
	      UARTTxMessage->isNew = FALSE;
		  CurrentTxStatus = STOP;
	  }
      else {
          isTxFifoFull = TRUE;
      }
  }
  
  if (isTxFifoFull == TRUE) {
	  isComingUartTxTrigger = (uint8_t)TRUE;
  }
  else {
	  if (isComingUartTxTrigger == (uint8_t)TRUE) {
		  isComingUartTxTrigger = (uint8_t)FALSE;
		  DBG002_TriggerUartTxIntrpt();
	  }
  }
  
  s_ptrNextByte=ptrNextByte;
  s_ptrEndByte=ptrEndNextByte;
  s_UARTTxMessage=UARTTxMessage;
  s_CurrentTxStatus=CurrentTxStatus;
}

/* Initialize the UART physical interface */
void DBG002_lUARTInit(void* Handle) {
    /**
	 * initialise the UART peripheral as per the passed Handle
	 */
	DBG002_UARTInit(); 

   	/* Set UART FIFO transmit buffer interrupt priority */
	NVIC_SetPriority(9, 3); 
   	/* Set UART FIFO receive buffer interrupt priority */
	NVIC_SetPriority(10, 3);

    /* Enable FIFO transmit interrupt */
	NVIC_EnableIRQ(9);
    /* Enable FIFO receive interrupt */
	NVIC_EnableIRQ(10);
}

/* Flush all the messages available on circular buffer */
void DBG002_Flush(void)
{
	do {
        DBG002_TransmitBufferCallback();
	} while(isComingUartTxTrigger != FALSE);
}

/* Trigger the transmission of message from circular buffer. */
void DBG002_SendMessageToHost(void) {
  if(isComingUartTxTrigger == FALSE)
	  DBG002_TriggerUartTxIntrpt();
}

/*CODE_BLOCK_END*/

