/*******************************************************************************
**  DAVE App Name : DBG002       App Version: 1.0.22               
**  This file is generated by DAVE, User modification to this file will be    **
**  overwritten at the next code generation.                                  **
*******************************************************************************/


/*CODE_BLOCK_BEGIN[DBG002_UART.c]*/
/*******************************************************************************
 Copyright (c) 2011, Infineon Technologies AG                                 **
 All rights reserved.                                                         **
                                                                              **
 Redistribution and use in source and binary forms, with or without           **
 modification,are permitted provided that the following conditions are met:   **
                                                                              **
 *Redistributions of source code must retain the above copyright notice,      **
 this list of conditions and the following disclaimer.                        **
 *Redistributions in binary form must reproduce the above copyright notice,   **
 this list of conditions and the following disclaimer in the documentation    **
 and/or other materials provided with the distribution.                       **
 *Neither the name of the copyright holders nor the names of its contributors **
 may be used to endorse or promote products derived from this software without** 
 specific prior written permission.                                           **
                                                                              **
 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"  **
 AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE    **
 IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE   **
 ARE  DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE   **
 LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR         **
 CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF         **
 SUBSTITUTE GOODS OR  SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS    **
 INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN      **
 CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)       **
 ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE   **
 POSSIBILITY OF SUCH DAMAGE.                                                  **
                                                                              **
 To improve the quality of the software, users are encouraged to share        **
 modifications, enhancements or bug fixes with Infineon Technologies AG       **
 dave@infineon.com).                                                          **
                                                                              **
********************************************************************************
**                                                                            **
**                                                                            **
** PLATFORM : Infineon XMC4000 Series   			                          **
**                                                                            **
** COMPILER : Compiler Independent                                            **
**                                                                            **
** AUTHOR   : App Developer                                                   **
**                                                                            **
** MAY BE CHANGED BY USER [yes/no]: Yes                                       **
**                                                                            **
** MODIFICATION DATE : Dec 12, 2012                                           **
**                                                                            **
*******************************************************************************/
/*******************************************************************************
**                      Author(s) Identity                                    **
********************************************************************************
**                                                                            **
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** NPJ          App Developer                                                 **
*******************************************************************************/
/**
 * @file DBG002_UART.c
 * 
 * @App Version DBG002 <1.0.22>
 *
 * @brief   This file provides implementation of UART read write functions.  
 *          Limitations 
 *           a) Read/Write functions are non reentrant.
 *           b) No support for DMA mode
 */
 
/*******************************************************************************
 ** INCLUDE FILES                                                             **
 ******************************************************************************/

#include <DAVE3.h>
#include "../../inc/DBG002/DBG002_UART.h"


/*******************************************************************************
**                      Private Macro Definitions                             **
*******************************************************************************/
  /* System Core clock frequency in MHz */

#define DBG002_UARTCLOCK  32

/*******************************************************************************
**                 Private Function Declarations:
*******************************************************************************/

/* Initializes the App based on User provide configuration. */
void DBG002_UARTlInit (const DBG002_UARTHandleType* Handle);

/*******************************************************************************
**                      Global Constant Definitions                           **
*******************************************************************************/

/*******************************************************************************
**                      Private Function Definitions                          **
*******************************************************************************/
/* Initializes the App based on User provide configuration. */

 
void DBG002_UARTlInit (const DBG002_UARTHandleType* Handle)
{
  USIC_CH_TypeDef* UartRegs = Handle->UartRegs;

  
 /* <<<DD_DBG002_UARTAPI_1>>>*/
 
  /** UART initialization  */
  
  
	// Disable clock gating to USIC0
	SCU_GENERAL->PASSWD = 0x000000C0UL; // disable bit protection
	SCU_CLK->CGATCLR0 |= SCU_CLK_CGATCLR0_USIC0_Msk;
	SCU_GENERAL->PASSWD = 0x000000C3UL; // enable bit protection
  
  
  /* Enable the USIC Channel */
  UartRegs->KSCFG |= (((uint32_t)( 0x01UL  & USIC_CH_KSCFG_MODEN_Msk)) | \
  ((uint32_t)(0x01UL   << USIC_CH_KSCFG_BPMODEN_Pos) &  (uint32_t)USIC_CH_KSCFG_BPMODEN_Msk));
  
  /* Configuration of USIC Channel Fractional Divider */

  /* Fractional divider mode selected */
  UartRegs->FDR |= ((uint32_t)( 2UL << USIC_CH_FDR_DM_Pos) \
                    & (uint32_t)USIC_CH_FDR_DM_Msk);
  
  /* Step value */
  UartRegs->FDR |= ((Handle->BGR_STEP) & (uint32_t)USIC_CH_FDR_STEP_Msk);
          
  /* The PreDivider for CTQ, PCTQ = 0  */
  /* The Denominator for CTQ, DCTQ = 16 */
    
  UartRegs->BRG |= \
	  ((((uint32_t)(Handle->BGR_PCTQ) << USIC_CH_BRG_PCTQ_Pos) & \
		  	     USIC_CH_BRG_PCTQ_Msk) | \
      (((uint32_t)(Handle->BGR_DCTQ) << USIC_CH_BRG_DCTQ_Pos) & \
	     USIC_CH_BRG_DCTQ_Msk) | \
      (((uint32_t)(Handle->BGR_PDIV) << USIC_CH_BRG_PDIV_Pos) &  \
	     USIC_CH_BRG_PDIV_Msk));
 
  /* Configuration of USIC Shift Control */
  
  /* Transmit/Receive LSB first is selected  */
  /* Transmission Mode (TRM) = 1  */
  /* Passive Data Level (PDL) = 1 */
  UartRegs->SCTR |= (((uint32_t)(0x01UL  << USIC_CH_SCTR_PDL_Pos) & \
		  (uint32_t)USIC_CH_SCTR_PDL_Msk ) | \
    ((uint32_t)(0x01UL  <<  USIC_CH_SCTR_TRM_Pos ) &   (uint32_t)USIC_CH_SCTR_TRM_Msk ));
  /* Set Word Length (WLE) & Frame Length (FLE) */
  UartRegs->SCTR |= (((uint32_t)((uint32_t)Handle->DataBits  << USIC_CH_SCTR_FLE_Pos) & \
		  (uint32_t)USIC_CH_SCTR_FLE_Msk ) | \
  ((uint32_t)((uint32_t)Handle->DataBits  << USIC_CH_SCTR_WLE_Pos) &  (uint32_t)USIC_CH_SCTR_WLE_Msk));

       
  /* Configuration of USIC Transmit Control/Status Register */ 
  /* TBUF Data Enable (TDEN) = 1 */
  /* TBUF Data Single Shot Mode (TDSSM) = 1 */
	
  UartRegs->TCSR |= (((uint32_t)(0x01UL  << USIC_CH_TCSR_TDEN_Pos) & \
		  (uint32_t)USIC_CH_TCSR_TDEN_Msk ) | \
    ((uint32_t)(0x01UL  << USIC_CH_TCSR_TDSSM_Pos) & (uint32_t)USIC_CH_TCSR_TDSSM_Msk));

  /* Configuration of Protocol Control Register */ 
  /* Sample Mode (SMD) = 1 */
  /* 1 Stop bit is selected */   
  /* Sample Point (SP) = 2 */
  /* Pulse Length (PL) = 0 */
  
  UartRegs->PCR_ASCMode |= (((uint32_t)(0x01UL  & USIC_CH_PCR_ASCMode_SMD_Msk)) | \
    ((uint32_t)((uint32_t)Handle->StopBit  << USIC_CH_PCR_ASCMode_STPB_Pos) & \
    		(uint32_t)USIC_CH_PCR_ASCMode_STPB_Msk) | \
    ((uint32_t)((uint32_t)(Handle->BGR_SP)  << USIC_CH_PCR_ASCMode_SP_Pos) & \
    		(uint32_t)USIC_CH_PCR_ASCMode_SP_Msk) | \
    ((uint32_t)(0x01UL  << USIC_CH_PCR_ASCMode_RSTEN_Pos) & \
    		(uint32_t)USIC_CH_PCR_ASCMode_RSTEN_Msk) | \
    		((uint32_t)(0x00UL  << USIC_CH_PCR_ASCMode_IDM_Pos) & \
    				(uint32_t)USIC_CH_PCR_ASCMode_IDM_Msk));
  
  /* Configuration of Protocol Status Register */ 
  /* TBIF is set to simplify polling*/
  UartRegs->PSR_ASCMode |= ((uint32_t)(0x01UL  << USIC_CH_PSR_TBIF_Pos) & \
		  (uint32_t)USIC_CH_PSR_TBIF_Msk);
		                    
  /* Configuration of Transmitter Buffer Control Register */ 
    UartRegs->TBCTR &= ~(USIC_CH_TBCTR_LOF_Msk | USIC_CH_TBCTR_LIMIT_Msk);
    UartRegs->TBCTR |= ((uint32_t)Handle->TxLimit << USIC_CH_TBCTR_LIMIT_Pos);

  /* Configuration of Receiver Buffer Control Register */ 
    UartRegs->RBCTR &= ~(USIC_CH_RBCTR_LOF_Msk | USIC_CH_RBCTR_LIMIT_Msk);
    UartRegs->RBCTR |= ((uint32_t)Handle->RxLimit << USIC_CH_RBCTR_LIMIT_Pos) 
                    |  (USIC_CH_RBCTR_LOF_Msk);                     
   
  /* Configuration of Channel Control Register */ 
  /* parity generation is disabled*/
    UartRegs->CCR |= ( ((uint32_t)(UART_MODE  & USIC_CH_CCR_MODE_Msk)) | \
    (((uint32_t)Handle->Parity  << USIC_CH_CCR_PM_Pos) & \
    (uint32_t)USIC_CH_CCR_PM_Msk));
}

/*******************************************************************************
**                      Public Function Definitions                           **
*******************************************************************************/
void DBG002_UARTInit(void)
{
/* Reset the Peripheral*/
  DBG002_UARTlInit(&DBG002_UARTHandle0);
}



/*CODE_BLOCK_END*/



