/**
 * @file PMSMFOCSL01_Conf.c
 * 
 * @brief This file contains the configuration parameters for all instances of 
 * the PMSMFOCSL01 App.
 */

/*******************************************************************************
** INCLUDE FILES:
*******************************************************************************/
#include <DAVE3.h>

/**
 * @cond INTERNAL_DOCS
 */

/*******************************************************************************
** PRIVATE MACRO DEFINITIONS:
*******************************************************************************/

/*******************************************************************************
** PRIVATE TYPE DEFINITIONS:
*******************************************************************************/

/*******************************************************************************
** PRIVATE FUNCTION DECLARATIONS:
*******************************************************************************/

/*******************************************************************************
** PRIVATE CONSTANT DEFINITIONS:
*******************************************************************************/

/*******************************************************************************
** GLOBAL VARIABLE DEFINITIONS:
*******************************************************************************/

 
/* Scaling Value for Motor Control Parameters
 * ActualValue                 = Scale * TargetValue
 * Speed Scale                 = 0.5086214789269692
 * Phase Voltage Scale         = 0.0018005675912017574
 * Voltage (alpha, beta) Scale = 0.002965102686487406
 * Voltage (d, q) Scale        = 0.01953125
 * Current Scale               = 7.62939453125E-4
 * Current (alpha, beta) Scale = 0.00152587890625
 * Current (d, q) Scale        = 0.0018531891790546284
 * Speed Kp Scale              = 0.002
 * Speed Ki Sclae              = 0.0000305
 * Current Kp Scale            = 0.002
 * Current Ki Scale            = 0.0000305
 */
MOTORLIBS_PT1HandleType PMSMFOCSL01_PT1VoltCompHandle0 = {
  .Z1    =(int32_t)47,
  .Ymax  =(int32_t)(0x70000000),
  .Ymin  =(int32_t)0,
  .PT1buf=(int32_t)0x783f87c
};
MOTORLIBS_PT1HandleType PMSMFOCSL01_PT1SpeedHandle0 = {
  .Z1    =(int32_t)47,
  .Ymax  =(int32_t)(0x70000000),
  .Ymin  =(int32_t)(-0x70000000),
  .PT1buf=(int32_t)0
};

MOTORLIBS_PT1HandleType PMSMFOCSL01_PT12alphaHandle0 = {
  .Z1    =(int32_t)477,
  .Z2    =(int32_t)47,
  .Ymax  =(int32_t)(0x70000000),
  .Ymin  =(int32_t)(-0x70000000),
  .PT1buf=(int32_t)0
};
MOTORLIBS_PT1HandleType PMSMFOCSL01_PT12betaHandle0 = {
  .Z1    =(int32_t)477,
  .Z2    =(int32_t)47,
  .Ymax  =(int32_t)(0x70000000),
  .Ymin  =(int32_t)(-0x70000000),
  .PT1buf=(int32_t)0
};

// 30.10.2016
MOTORLIBS_PT1HandleType PMSMFOCSL01_PT12PLLHandle0 = {
  .Z1    =(int32_t)477,
  .Z2    =(int32_t)47,
  .Ymax  =(int32_t)(0x70000000),
  .Ymin  =(int32_t)(-0x70000000),
  .PT1buf=(int32_t)0
};
//
//

MOTORLIBS_PIHandleType PMSMFOCSL01_PISpeedHandle0 = {
  .Kp=(uint16_t)1600,
  .Ki=(uint16_t)9,
  .Ibuf=0,
  .Yimax=(int32_t)234881024,  
  .Yimin=-1*(int32_t)234881024,
  .Ymax=(int16_t)2560,  
  .Ymin=-1*(int16_t)2560,
  .PiOutVal=0    
};
MOTORLIBS_PIHandleType PMSMFOCSL01_PIIqHandle0 = {
  .Kp=(uint16_t)3755,
  .Ki=(uint16_t)41,
  .Ibuf=0,
  .Yimax=(int32_t)234881024,   
  .Yimin=-1*(int32_t)234881024,
  .Ymax=(int16_t)20480,  
  .Ymin=-1*(int16_t)20480,
  .PiOutVal=0        
};
MOTORLIBS_PIHandleType PMSMFOCSL01_PIIdHandle0 = {
  .Kp=(uint16_t)3755,  
  .Ki=(uint16_t)41,
  .Ibuf=0,
  .Yimax=(int32_t)234881024,   
  .Yimin=-1*(int32_t)234881024,
  .Ymax=(int16_t)20480, 
  .Ymin=-1*(int16_t)20480,
  .PiOutVal=0        
};

//30.10.2016.
MOTORLIBS_PIHandleType PMSMFOCSL01_PLLHandle0 = {
  .Kp=(uint16_t)1600,
  .Ki=(uint16_t)9,
  .Ibuf=0,
  .Yimax=(int32_t)234881024,
  .Yimin=-1*(int32_t)234881024,
  .Ymax=(int16_t)2560,
  .Ymin=-1*(int16_t)2560,
  .PiOutVal=0
};
//
//

PMSMFOCSL01_StartupHandleType PMSMFOCSL01_StartupHandle0 =
{   
  .VFOffset  =(uint32_t)277,
  .VFConst   =(uint32_t)628,
  .Angle      =(int16_t)0
};


PMSMFOCSL01_DynamicHandleType PMSMFOCSL01_DynamicHandle0 =
{   
  .IqStartup    =(uint32_t)500,
  .State              = PMSMFOCSL01_UNINITIALIZED
};
    

const PMSMFOCSL01_HandleType PMSMFOCSL01_Handle0 =
{

  .SVMAppPtr          = &PWMSVM01_Handle0,
  .H_Ptr              = &PMSMFOCSL01_DynamicHandle0,
  .StartupHPtr        = &PMSMFOCSL01_StartupHandle0,
  .SpeedPIPtr      = &PMSMFOCSL01_PISpeedHandle0,
  .IqPIPtr           = &PMSMFOCSL01_PIIqHandle0,
  .IdPIPtr            = &PMSMFOCSL01_PIIdHandle0,
  .VoltCompPT1Ptr     = &PMSMFOCSL01_PT1VoltCompHandle0,
  .SpeedPT1Ptr        = &PMSMFOCSL01_PT1SpeedHandle0,
  .ValphaPT12Ptr          = &PMSMFOCSL01_PT12alphaHandle0,
  .VbetaPT12Ptr          = &PMSMFOCSL01_PT12betaHandle0,  
  
  //30.10.2016.
  .PLLPIPtr			= &PMSMFOCSL01_PLLHandle0,
  .PLLPT12Ptr          = &PMSMFOCSL01_PT12PLLHandle0,

  //

  .ADCReqSrcPtrA       = &ADC002_Handle0,
  
  .ADCReqSrcPtrB       = &ADC002_Handle0,
  .ADCReqSrcPtrC       = &ADC002_Handle0,
  
  .kNormVolt           = (uint32_t)58,
      
  .kNormVoltAlphaBeta  = (uint32_t)97,
      
  .kNormVoltdq         = (uint32_t)639,
      
  .kNormkp             = (uint32_t)512,
      
  .kNormki             = (uint32_t)32767,
      
  .kNormSpeed          = (uint32_t)16666,
      
  .kNormCurrent        =(uint32_t)24,
      
  .kNormCurrentAlphaBeta=(uint32_t)49,
      
  .kNormCurrentdq      =(uint32_t)60,
      
  .kNormSlewRate       =(uint32_t)10172, 
      
  .kAmplitudeMax       =(uint32_t)13329,
      
  .kAmplitudeMin       =(uint32_t)0,
      
  .kUserStartSpeedRef  =(int32_t)98,
  .kUserStartSpeedThreshold  = (int32_t)393,
      
  .kUserEndSpeedRef    =(int32_t)2949,
      
  .kSpeedMaxTarget     =(uint32_t)5426, 
      
  .kRampCounter        =(uint32_t)20,
      
  .kSlewRate           =(uint32_t)500,
      
  .kSpecifiedVolt      =(uint32_t)1924,
      
  .kPolePair           =(uint32_t)4,
      
  .kPotScaleVal        =(uint32_t)1356,
      
  .kMotorResistance    =(uint32_t)28877,
  
  .kResistanceScale    =(int32_t)2,
      
  .kMotorInductance    =(uint32_t)10131,
  
  .kInductanceScale    =(int32_t)0,
      
  .kSpeedControlRate   =(uint32_t)9,
      
  .kCurrentControlRate =(uint32_t)3,
  
  .kAmpOffset          =(uint32_t)2048,
  
  .kBootStrapEnable     = 0U,
  
  .kBootStrapCount      = 40U,  
  
  .kAmpBiasVoltCal     =(uint32_t)1,    
  .Enable              = {/* Enable(1)/Disable(0) POT for Speed Input*/
                          0U,                 
                          /* Enable(1)/Disable(0) Voltage Compensation */                          
                          0U,
                          /* Enable(1)/Disable(0) V/F Startup */                          
                          1U,
                          /* Enable(1)/Disable(0) Trap*/
                          1U                               
                          },
  .kMotDirection     = (int32_t)PMSMFOCSL01_FORDIR ,
  
  .kAmplitudeScale     =(uint32_t)480,  
  
  .kCCRIntSelect       =(uint32_t)0x2 
};

PMSMFOCSL01_ISRHandleType PMSMFOCSL01_PMISRHandle0 = {
  .Node_Id  = (uint16_t)25 , 
  .Priority = (uint16_t)3, 
  .Sub_Pri  = (uint16_t)0    
};

PMSMFOCSL01_ISRHandleType PMSMFOCSL01_TrapISRHandle0 = {
  .Node_Id  = (uint16_t)26 , 
  .Priority = (uint16_t)1, 
  .Sub_Pri  = (uint16_t)0    
};

/* Interrupt Node for current measurement (slice 3 compare match) is NOT MAPPED FOR APP INSTANCE 0*/


/* The variable is used to store the address of the Handles */
PMSMFOCSL01_HandleType*  PMSMFOCSL01_HandleArray[PMSMFOCSL01_NUM_INSTANCES] = 
                   {
                     (PMSMFOCSL01_HandleType*)(void*) &PMSMFOCSL01_Handle0
                   };
PMSMFOCSL01_ISRHandleType* PMSMFOCSL01_PMISRHandleArray[PMSMFOCSL01_NUM_INSTANCES] = 
                   {
                     (PMSMFOCSL01_ISRHandleType*)(void*) &PMSMFOCSL01_PMISRHandle0
                   };

PMSMFOCSL01_ISRHandleType* PMSMFOCSL01_TrapISRHandleArray[PMSMFOCSL01_NUM_INSTANCES] = 
                   {
                     (PMSMFOCSL01_ISRHandleType*)(void*) &PMSMFOCSL01_TrapISRHandle0
                   };
                  
PMSMFOCSL01_ISRHandleType* PMSMFOCSL01_CMISRHandleArray[PMSMFOCSL01_NUM_INSTANCES] = 
                   {
                     (PMSMFOCSL01_ISRHandleType*)(void*)NULL
                   };
                   
/*******************************************************************************
** PUBLIC FUNCTION DEFINITIONS:
*******************************************************************************/

/*******************************************************************************
** FUNCTION LIKE MACRO DEFINITIONS:
*******************************************************************************/

/*******************************************************************************
** PRIVATE VARIABLES:
*******************************************************************************/

/*******************************************************************************
** PRIVATE FUNCTION DEFINITIONS:
*******************************************************************************/

/**
 * @endcond
 */
 
/*CODE_BLOCK_END*/ 


