/*CODE_BLOCK_BEGIN[PWMSVM01.c]*/
/*******************************************************************************
 Copyright (c) 2014, Infineon Technologies AG                                 **
 All rights reserved.                                                         **
                                                                              **
 Redistribution and use in source and binary forms, with or without           **
 modification,are permitted provided that the following conditions are met:   **
                                                                              **
 *Redistributions of source code must retain the above copyright notice,      **
 this list of conditions and the following disclaimer.                        **
 *Redistributions in binary form must reproduce the above copyright notice,   **
 this list of conditions and the following disclaimer in the documentation    **
 and/or other materials provided with the distribution.                       **
 *Neither the name of the copyright holders nor the names of its contributors **
 may be used to endorse or promote products derived from this software without**
 specific prior written permission.                                           **
                                                                              **
 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"  **
 AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE    **
 IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE   **
 ARE  DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE   **
 LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR         **
 CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF         **
 SUBSTITUTE GOODS OR  SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS    **
 INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN      **
 CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)       **
 ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE   **
 POSSIBILITY OF SUCH DAMAGE.                                                  **
                                                                              **
 To improve the quality of the software, users are encouraged to share        **
 modifications, enhancements or bug fixes with Infineon Technologies AG       **
 dave@infineon.com).                                                          **
                                                                              **
********************************************************************************
**                                                                            **
** PLATFORM : Infineon XMC4000/XMC1000 Series                                 **
**                                                                            **
** COMPILER : Compiler Independent                                            **
**                                                                            **
** AUTHOR   : App Developer                                                   **
**                                                                            **
** NOTE     : Any Changes made to this file will be overwritten during Code   **
**            Generation                                                      **
**                                                                            *
********************************************************************************
 **                           Revision History                                **  
 *******************************************************************************
 * 04 September 2012   v1.0.0    Initial version
 * 19 October   2012   v1.0.4    IO App instance number handling changed
 * 06 December  2012   v1.0.6    IO004 App is used for Enable pin
 * 03 April     2013   v1.0.8    SIN table size increased (256 ->1024)
 * 25 April     2013   v1.0.12   Added support for devices - XMC1302
 * 28 May       2013   v1.0.22   Added: Pseudo zero vector SVM and CORDIC option
 *                               for XMC13 device
 * 21 June      2013   v1.0.24   Added support for devices - XMC44 and XMC42
 * 24 July      2013   v1.0.26   Added support for phase current measurement,
 *                               Modified CORDIC Function,
 *                               Max amplitude limited based on SVM Mode.
 * 23 September 2013   v1.0.28   CCU8 slice constraint removed  
 * 26 November  2013   v1.0.30   Added Pseudo Zero Vector support for XMC4x 
 *                               device.
 * 30 January   2014   v1.0.36   Updated PWMSVM01.C and PWMSVM01.h file to 
 *                               static file.
 *                               Added Pseudo Zero Vector support for XMC4x device.
 *                               Updated Phase current measurement configuration 
 *                               and slice number for Phases.
 *                               XMC4000 Device support extended for XMC4500 AC step, 
 *                               XMC4400 AB Step and XMC4200 AB Step. 
 *                               DBG002 related MACRO has been updated. 
 ******************************************************************************/
/**
 * @file PWMSVM01.c
 * @brief   This file contains the implementation of all public and private
 * functions of the PWMSVM01 App. This App implements the SVM algorithm for
 * sinusoidal commutation.It supports Symmetric and Asymmetric SVM along with
 * 5-Segment and 7-Segment scheme.This App also supports Pseudozero vector SVM.
 */
/******************************************************************************
**                      Include Files                                         **
*******************************************************************************/
/* Included header file*/

#include <DAVE3.h>

/*******************************************************************************
**                      Private Macro Definitions                             **
*******************************************************************************/
/********************DUMMY DEFINTIONS OF DEBUG LOG MACROS**********************/
/*These definitions are included here to avoid compilation errors,
 since the DBG002 app is not part of the project. All the macros are defined
 as empty*/
#ifndef _DBG002_H_

#define DBG002_RegisterCallBack(A,B,C)
#define DBG002_I(e)
#define DBG002_IG(e,g)
#define DBG002_IH(e,h)
#define DBG002_IP(e,p)
#define DBG002_IGH(e,g,h)
#define DBG002_IGP(e,g,p)
#define DBG002_IHP(e,h,p)
#define DBG002_IGHP(e,g,h,p)
#define DBG002_N(e)
#define DBG002_NG(e,g)
#define DBG002_NH(e,h)
#define DBG002_NP(e,p)
#define DBG002_NGH(e,g,h)
#define DBG002_NGP(e,g,p)
#define DBG002_NHP(e,h,p)
#define DBG002_NGHP(e,g,h,p)
#define DBG002_ID(e)
#define DBG002_IS(e)
#define DBG002_ISG(e,g)
#define DBG002_SAFETY_CRITICAL(groupid,messageid,length,value)
#define DBG002_CRITICAL(groupid,messageid,length,value)
#define DBG002_ERROR(groupid,messageid,length,value)
#define DBG002_WARNING(groupid,messageid,length,value)
#define DBG002_INFO(groupid,messageid,length,value)
#define DBG002_TRACE(groupid,messageid,length,value)
#define DBG002_FUNCTION_ENTRY(GID, Status)
#define DBG002_FUNCTION_EXIT(GID, Status)

#define DBG002_MESSAGEID_LITERAL

#endif/* End of defintions of dummy Debug Log macros*/

#define APP_GID DBG002_GID_PWMSVM01

/**
 * @cond INTERNAL_DOCS
 */

/*******************************************************************************
**                        Private Type Definitions                            **
*******************************************************************************/
/*******************************************************************************
 *                 Private Function declarations                               *
 ******************************************************************************/
/**
 * @brief This function initializes CCU8x_CC8y global and slice registers \n
 * @param[in] HandlePtr Handle of the PWMSVM01 App
 * @return void
 * <BR>
 *
 * <b>Reentrancy:  Yes</b><BR>
 * <b>Sync/Async:  Synchronous</b><BR>
 */
static void PWMSVM01_lInit(const PWMSVM01_HandleType* HandlePtr);

/**
 * @brief This function calculates the compare values for the Symmetric
 * 7-Segment SVM \n
 * @param[in] HandlePtr Handle of the PWMSVM01 App
 * @return void
 * <BR>
 *
 * <b>Reentrancy:  Yes</b><BR>
 * <b>Sync/Async:  Synchronous</b><BR>
 */
static void PWMSVM01_lCalCmpValueSym7(const PWMSVM01_HandleType* HandlePtr);

/**
 * @brief This function calculates the compare values for the Symmetric
 * 5-Segment SVM \n
 * @param[in] HandlePtr Handle of the PWMSVM01 App
 * @return void
 * <BR>
 *
 * <b>Reentrancy:  Yes</b><BR>
 * <b>Sync/Async:  Synchronous</b><BR>
 */
static void PWMSVM01_lCalCmpValueSym5(const PWMSVM01_HandleType* HandlePtr);
/**
 * @brief This function calculates the compare values for the Asymmetric
 * 7-Segment SVM \n
 * @param[in] HandlePtr Handle of the PWMSVM01 App
 * @return void
 * <BR>
 *
 * <b>Reentrancy:  Yes</b><BR>
 * <b>Sync/Async:  Synchronous</b><BR>
 */
static void PWMSVM01_lCalCmpValueAsym7(const PWMSVM01_HandleType* HandlePtr);
/**
 * @brief This function calculates the compare values for the Asymmetric
 * 5-Segment SVM \n
 * @param[in] HandlePtr Handle of the PWMSVM01 App
 * @return void
 * <BR>
 *
 * <b>Reentrancy:  Yes</b><BR>
 * <b>Sync/Async:  Synchronous</b><BR>
 */
static void PWMSVM01_lCalCmpValueAsym5(const PWMSVM01_HandleType* HandlePtr);
/**
 * @brief This is the library function to multiply the two numbers in Q15 format.
 * @param[in] Param1 Parameter 1 
 * @param[in] Param2 Parameter 2
 * @param[in] Scale 2^scale
 * @return Result Multiplication result
 * <BR>
 *
 * <b>Reentrancy:  Yes</b><BR>
 * <b>Sync/Async:  Synchronous</b><BR>
 */
static uint16_t PWMSVM01_MulQ15
(
		uint16_t Param1,
		uint16_t Param2,
		uint16_t Scale
		);
#if (UC_FAMILY == XMC1)
/**
 * @brief This function calculates segment time using CORDIC. 
 * @param[in] HandlePtr Handle of the PWMSVM01 App
 * @param[in] Amplitude Amplitude
 * @param[in] Angle Input angle
 * @return void
 * <BR>
 *
 * <b>Reentrancy:  Yes</b><BR>
 * <b>Sync/Async:  Synchronous</b><BR>
 */
static void PWMSVM01_lTimecalcUsingCORDIC
      (
		const PWMSVM01_HandleType* HandlePtr,
		uint16_t Amplitude,
		uint16_t Angle
);
#endif
/**
 * @brief This function disable the inverter.
 * @param[in] HandlePtr Handle of the PWMSVM01 App
 * @return void
 * <BR>
 *
 * <b>Reentrancy:  Yes</b><BR>
 * <b>Sync/Async:  Synchronous</b><BR>
 */
static void PWMSVM01_lInverterDisable(const PWMSVM01_HandleType* HandlePtr);
/**
 * @brief This function calculates segment time using Look up table. 
 * @param[in] HandlePtr Handle of the PWMSVM01 App
 * @param[in] Angle Input angle
 * @param[in] Amplitude Amplitude
 * @return void
 * <BR>
 *
 * <b>Reentrancy:  Yes</b><BR>
 * <b>Sync/Async:  Synchronous</b><BR>
 */
static void PWMSVM01_lTimecalcUsingLUT
(
		const PWMSVM01_HandleType* HandlePtr,
		uint16_t Amplitude,
		uint16_t Angle
		);
      /**
 * @brief  This function calculates the CCU8 slice compare value
 * for Asymmetric 7-segment Pseudo zero vector SVM technique.
 * @param[in] HandlePtr Handle of the PWMSVM01 App
 * @return void
 * <BR>
 *
 * <b>Reentrancy:  Yes</b><BR>
 * <b>Sync/Async:  Synchronous</b><BR>
 */
static  void PWMSVM01_lCalc4av7segmentCompVal
(
		const PWMSVM01_HandleType* HandlePtr
		);
/**
 * @brief  This function calculates the CCU8 slice compare value
 * for Asymmetric 5-segment Pseudo zero vector SVM technique.
 * @param[in] HandlePtr Handle of the PWMSVM01 App
 * @return void
 * <BR>
 *
 * <b>Reentrancy:  Yes</b><BR>
 * <b>Sync/Async:  Synchronous</b><BR>
 */
static void PWMSVM01_lCalc3av5segmentCompVal
(
		const PWMSVM01_HandleType* HandlePtr
		);
/**
 * @brief  This function update the compare register values based on the sector
 *  number
 * @param[in] HandlePtr Handle of the PWMSVM01 App
 * @return void
 * <BR>
 *
 * <b>Reentrancy:  Yes</b><BR>
 * <b>Sync/Async:  Synchronous</b><BR>
 */
static void PWMSVM01_lUpdateDcLinkComRes (const PWMSVM01_HandleType* HandlePtr);
/**
 * Function pointer array to store the function pointers for updating the
 * compare values based on the SVM type.
 */
void (*PWMSVM01_UpdateCmpValuePtr[6])(const PWMSVM01_HandleType *HandlePtr) =
{
    PWMSVM01_lCalCmpValueSym7,
    PWMSVM01_lCalCmpValueSym5,
    PWMSVM01_lCalCmpValueAsym7,
    PWMSVM01_lCalCmpValueAsym5,
    PWMSVM01_lCalc3av5segmentCompVal,
    PWMSVM01_lCalc4av7segmentCompVal
};

/*******************************************************************************
**                      Imported Global Variables                             **
*******************************************************************************/
/**
 * This is the sine table used for SVM algorithm.
 */
extern const uint16_t Sinus60_tab[];
/*******************************************************************************
**                      Global Constant Definitions                           **
*******************************************************************************/

/*******************************************************************************
**                      Global Variable Definitions                           **
*******************************************************************************/

/*******************************************************************************
**                      Private Constant Definitions                          **
*******************************************************************************/

/*******************************************************************************
**                 Function like macro definitions                            **
*******************************************************************************/

/*******************************************************************************
**                      Private Function Definitions                          **
*******************************************************************************/
/**
 * This function disable the inverter
 */
static void PWMSVM01_lInverterDisable(const PWMSVM01_HandleType* HandlePtr)
{
	IO004_HandleType IOHandle = *(HandlePtr->InverterPinPtr);
	if (HandlePtr->kInverterPin == 2U)
	{
		IO004_SetPin(IOHandle);
	}
	else
	{
		IO004_ResetPin(IOHandle);
	}
}
/**
 * This function initializes all the three phases as per the user configurations
 */
static void PWMSVM01_lInit(const PWMSVM01_HandleType* HandlePtr)
{
  uint32_t Index;
  
  if (HandlePtr->DynamicHdlPtr->State == PWMSVM01_UNINITIALIZED)
  { 
    /*Inverter Enable pin level is set to passive level.*/
    PWMSVM01_lInverterDisable(HandlePtr);
    for (Index = 0U; Index < PWMSVM01_NUMBERPHASE; Index++)
    {
      HandlePtr->PhasePtr[Index]->PRS = (uint32_t)HandlePtr->kPeriod;
      HandlePtr->PhasePtr[Index]->CHC = (uint32_t)HandlePtr->kAsymmetricPWM;
      HandlePtr->PhasePtr[Index]->CR1S = 0U;
      HandlePtr->PhasePtr[Index]->CR2S = 0U;
      HandlePtr->PhasePtr[Index]->DTC |= 
          ((uint32_t)HandlePtr->kDeadTimePrescaler << CCU8_CC8_DTC_DTCC_Pos) |
          (uint32_t)0xD;
      HandlePtr->PhasePtr[Index]->PSL |= HandlePtr->kPassiveLevel;
      HandlePtr->PhasePtr[Index]->DC1R = HandlePtr->kDeadTime;
      HandlePtr->PhasePtr[Index]->TC  |= (uint32_t)(HandlePtr->kPWMType);
      
      /*All three slices are configured in external start mode with rising egde*/
      HandlePtr->PhasePtr[Index]->INS   |= (uint32_t)0x10000;
      /*External Start Functionality is mapped to Event 0*/
      HandlePtr->PhasePtr[Index]->CMC  |= 1U;
      /* if trap is enabled, configure trap level*/
      if (HandlePtr->kEnableTrap == 1U)
      {
        HandlePtr->PhasePtr[Index]->TC  |= ((uint32_t)0x00060000|
            ((uint32_t)HandlePtr->kTrapExitControl << CCU4_CC4_TC_TRPSW_Pos))|
            ((uint32_t)HandlePtr->kTrapSync << CCU4_CC4_TC_TRPSE_Pos);
        HandlePtr->PhasePtr[Index]->INS |= 
            ((uint32_t)HandlePtr->kTrapLevel << CCU8_CC8_INS_EV2LM_Pos);       
      }
    }
	/* Enable the shadow transfer for all three slices */
    HandlePtr->GlobalPtr->GCSS  |= (uint32_t)(((uint32_t)0x01 << 
    		((uint32_t)4*HandlePtr->kPhWSliceNo))
        | ((uint32_t)0x01 << ((uint32_t)4 * (uint32_t)HandlePtr->kPhVSliceNo))
        | ((uint32_t)0x01 << ((uint32_t)4 * (uint32_t)HandlePtr->kPhUSliceNo)));

    /*if hardware trigger is enable for current measurement*/     
    if (HandlePtr->kTriggerControl == 1U)
    {  
      /* Phase current measurement */
      if (HandlePtr->kExtTriggerCMType == (uint8_t)PWMSVM01_PHASECM)
      {
        /*Update the Current Trigger Slice period register*/
        HandlePtr->CurrentTriggerPtr->PRS = HandlePtr->kPeriod;
       /*Shadow Compare Register 1*/
        HandlePtr->CurrentTriggerPtr->CR1S =(((uint32_t)HandlePtr->kPeriod)>>2);

        /*Shadow Compare Register 2*/
        HandlePtr->CurrentTriggerPtr->CR2S =(((uint32_t)HandlePtr->kPeriod)>>1);

        /*Enable center aligned without single shot mode*/
        HandlePtr->CurrentTriggerPtr->TC |= 1U;

        HandlePtr->CurrentTriggerPtr->INTE |= 2U;

        /*Slice 83  are configured in external start mode with rising egde*/
        HandlePtr->CurrentTriggerPtr->INS       |= 0x10000U;

        /*External Start Functionality is mapped to Event 0*/
        HandlePtr->CurrentTriggerPtr->CMC      |= 1U;

         /*Enable the shadow transfer*/
        HandlePtr->GlobalPtr->GCSS |=
        		(uint32_t) ((uint32_t)1 << 
        				((uint32_t)4*HandlePtr->kCurrentTrigSliceNo));
      }
      /* DC link current measurement */
      else if (HandlePtr->kExtTriggerCMType == (uint8_t)PWMSVM01_DCLINKCM)
      { 
        /*Update the Current Trigger Slice period register*/
        HandlePtr->CurrentTriggerPtr->PRS = HandlePtr->kPeriod;
        
       /*Shadow Compare Register 1*/
        HandlePtr->CurrentTriggerPtr->CR1S =(((uint32_t)HandlePtr->kPeriod)>>2);
  
        /*Shadow Compare Register 2*/
        HandlePtr->CurrentTriggerPtr->CR2S =(((uint32_t)HandlePtr->kPeriod)>>1);
  
        if (HandlePtr->kPWMType == (uint8_t)PWMSVM01_STANDARD)
        {
          /*Enable center aligned without single shot mode*/
            HandlePtr->CurrentTriggerPtr->TC      |= 1U;
        }
        if (HandlePtr->kSVMConfig == 0U)
        {
          HandlePtr->CurrentTriggerPtr->INTE     |=(uint32_t)0x03C;
        }
        else
        {
          HandlePtr->CurrentTriggerPtr->INTE     |=(uint32_t)0x014;
        }
  
        /*Slice 83  are configured in external start mode with rising egde*/
        HandlePtr->CurrentTriggerPtr->INS       |= (uint32_t)0x10000;   
        
        /*External Start Functionality is mapped to Event 0*/
        HandlePtr->CurrentTriggerPtr->CMC      |= 1U;
  
         /*Enable the shadow transfer*/
        HandlePtr->GlobalPtr->GCSS |=
        		(uint32_t) ((uint32_t)1 << 
        				((uint32_t)4*HandlePtr->kCurrentTrigSliceNo));
      }
      /*if average current measurement is enable*/
      else
      {
        /*Update the Current Trigger Slice period register*/
        HandlePtr->CurrentTriggerPtr->PRS = HandlePtr->kPeriod;

        /*Shadow Compare Register 1*/
        HandlePtr->CurrentTriggerPtr->CR1S =(((uint32_t)HandlePtr->kPeriod)>>1);

         /* Enable Compare match event to trigger the current measurement*/
         HandlePtr->CurrentTriggerPtr->INTE     |=(uint32_t)0x4;

        /*Current measurement Slice is configured in external start
          mode with rising egde*/
        HandlePtr->CurrentTriggerPtr->INS       |= (uint32_t)0x10000;

        /*External Start Functionality is mapped to Event 0*/
        HandlePtr->CurrentTriggerPtr->CMC      |= 1U;

        /*Enable the shadow transfer*/
        HandlePtr->GlobalPtr->GCSS |=
        		(uint32_t) ((uint32_t)1 << 
        				((uint32_t)4 *HandlePtr->kCurrentTrigSliceNo));
      }
    }
    HandlePtr->DynamicHdlPtr->State = PWMSVM01_INITIALIZED;
  }  
}
/* Update the compare register values based on the sector number for DC link
   current measurement */

static void PWMSVM01_lUpdateDcLinkComRes (const PWMSVM01_HandleType* HandlePtr)
{
  PWMSVM01_DynamicHandleType* SVMPtr = HandlePtr->DynamicHdlPtr;
  
  if (HandlePtr->kExtTriggerCMType == (uint8_t)PWMSVM01_DCLINKCM)
  {
    HandlePtr->CurrentTriggerPtr->CR1S =
      (uint32_t)SVMPtr->V_TB+(uint32_t)((uint32_t)SVMPtr->Ta>>(uint32_t)1);
    HandlePtr->CurrentTriggerPtr->CR2S =
			(uint32_t)SVMPtr->V_TB +
			(uint32_t)((uint32_t)SVMPtr->Tb>>(uint32_t)1)+ (uint32_t)SVMPtr->Ta;
  }

  
}
/**
 * This function calculates the CCU8 slice compare value
 * for Symmetric 7-segment SVM.
 */
static void PWMSVM01_lCalCmpValueSym7(const PWMSVM01_HandleType* HandlePtr)
{
  PWMSVM01_DynamicHandleType* SVMPtr = HandlePtr->DynamicHdlPtr;
  
  if (SVMPtr->Ta < HandlePtr->kTmin)
  {
    SVMPtr->Ta = HandlePtr->kTmin;
  }
  
  if (SVMPtr->Tb < HandlePtr->kTmin)
  {
    SVMPtr->Tb = HandlePtr->kTmin;
  }
  
  HandlePtr->DynamicHdlPtr->V_TA = ((HandlePtr->kPeriod + \
      HandlePtr->DynamicHdlPtr->Ta) + HandlePtr->DynamicHdlPtr->Tb)>>1;
  HandlePtr->DynamicHdlPtr->V_TB = (uint16_t)( HandlePtr->kPeriod - \
  ( HandlePtr->DynamicHdlPtr->Ta + HandlePtr->DynamicHdlPtr->Tb ))>>1;
  
  PWMSVM01_lUpdateDcLinkComRes (HandlePtr);

  switch ((SVMPtr->Sector & 7U))
  {
    case 0:
      HandlePtr->PhasePtr[0]->CR1S =(uint32_t)SVMPtr->V_TB;
      HandlePtr->PhasePtr[1]->CR1S =(uint32_t)SVMPtr->V_TB+(uint32_t)SVMPtr->Ta;
      HandlePtr->PhasePtr[2]->CR1S =(uint32_t)SVMPtr->V_TA;
      break;
    case 1:
      HandlePtr->PhasePtr[0]->CR1S =(uint32_t)SVMPtr->V_TB+(uint32_t)SVMPtr->Ta;
      HandlePtr->PhasePtr[1]->CR1S =(uint32_t)SVMPtr->V_TB;
      HandlePtr->PhasePtr[2]->CR1S =(uint32_t)SVMPtr->V_TA;
      break;
    case 2:
      HandlePtr->PhasePtr[0]->CR1S = (uint32_t)SVMPtr->V_TA;
      HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TB;
      HandlePtr->PhasePtr[2]->CR1S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
      break;
    case 3:
      HandlePtr->PhasePtr[0]->CR1S = (uint32_t)SVMPtr->V_TA;
      HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
      HandlePtr->PhasePtr[2]->CR1S = (uint32_t)SVMPtr->V_TB;
      break;
    case 4:
      HandlePtr->PhasePtr[0]->CR1S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
      HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TA;
      HandlePtr->PhasePtr[2]->CR1S = (uint32_t)SVMPtr->V_TB;
      break;
    default:
      HandlePtr->PhasePtr[0]->CR1S = (uint32_t)SVMPtr->V_TB;
      HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TA;
      HandlePtr->PhasePtr[2]->CR1S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
      break;
  }    
  
}

/**
 * This function calculates the CCU8 slice compare value
 * for Symmetric 5-segment SVM.
 */
static void PWMSVM01_lCalCmpValueSym5(const PWMSVM01_HandleType* HandlePtr)
{
  PWMSVM01_DynamicHandleType* SVMPtr = HandlePtr->DynamicHdlPtr;
  
  if (SVMPtr->Ta < HandlePtr->kTmin)
  {
    SVMPtr->Ta = HandlePtr->kTmin;
  }
  if (SVMPtr->Tb < HandlePtr->kTmin)
  {
    SVMPtr->Tb = HandlePtr->kTmin;
  }
  HandlePtr->DynamicHdlPtr->V_TA = HandlePtr->kPeriod + 1U;
  HandlePtr->DynamicHdlPtr->V_TB = (HandlePtr->kPeriod - \
      HandlePtr->DynamicHdlPtr->Ta) - HandlePtr->DynamicHdlPtr->Tb;
  /* Update the compare register values based on the sector number */
  /* DC link current measurement */
  PWMSVM01_lUpdateDcLinkComRes (HandlePtr);
  switch ((SVMPtr->Sector & 7U))
  {
    case 0:
      HandlePtr->PhasePtr[0]->CR1S = (uint32_t)SVMPtr->V_TB;
      HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
      HandlePtr->PhasePtr[2]->CR1S = (uint32_t)SVMPtr->V_TA;
      break;
    case 1:
      HandlePtr->PhasePtr[0]->CR1S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
      HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TB;
      HandlePtr->PhasePtr[2]->CR1S = (uint32_t)SVMPtr->V_TA;
      break;
    case 2:
      HandlePtr->PhasePtr[0]->CR1S = (uint32_t)SVMPtr->V_TA;
      HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TB;
      HandlePtr->PhasePtr[2]->CR1S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
      break;
    case 3:
      HandlePtr->PhasePtr[0]->CR1S = (uint32_t)SVMPtr->V_TA;
      HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
      HandlePtr->PhasePtr[2]->CR1S = (uint32_t)SVMPtr->V_TB;
      break;
    case 4:
      HandlePtr->PhasePtr[0]->CR1S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
      HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TA;
      HandlePtr->PhasePtr[2]->CR1S = (uint32_t)SVMPtr->V_TB;
      break;
    default:
      HandlePtr->PhasePtr[0]->CR1S = (uint32_t)SVMPtr->V_TB;
      HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TA;
      HandlePtr->PhasePtr[2]->CR1S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
      break;
  }
  
}

/**
 * This function calculates the CCU8 slice compare value
 * for Asymmetric 7-segment SVM.
 */
static void PWMSVM01_lCalCmpValueAsym7(const PWMSVM01_HandleType* HandlePtr)
{
  PWMSVM01_DynamicHandleType* SVMPtr = HandlePtr->DynamicHdlPtr;
  
  /* check if Ta or Tb is not less than Tmin*/
  if (SVMPtr->Ta < HandlePtr->kTmin)
  {
    SVMPtr->Ta = 2U * (SVMPtr->Ta);
    if (SVMPtr->Ta < HandlePtr->kTmin)
    {
      SVMPtr->Ta = HandlePtr->kTmin;
    }
    SVMPtr->Ta2 = SVMPtr->Ta;
  }
  else
  {
    SVMPtr->Ta2=0U;
  }
  /*  7 -Segment Tb value Calcuation */
  if (SVMPtr->Tb < HandlePtr->kTmin)
  {
    SVMPtr->Tb= 2U * (SVMPtr->Tb);
    if (SVMPtr->Tb < HandlePtr->kTmin)
    {
      SVMPtr->Tb = HandlePtr->kTmin;
    }
    SVMPtr->Tb2 = SVMPtr->Tb;
  }
  else
  {
    SVMPtr->Tb2=0U;
  }
  HandlePtr->DynamicHdlPtr->V_TA = (HandlePtr->kPeriod + \
      HandlePtr->DynamicHdlPtr->Ta + HandlePtr->DynamicHdlPtr->Tb)>>1;
  HandlePtr->DynamicHdlPtr->V_TB = (uint16_t)((uint16_t)HandlePtr->kPeriod - \
      ((uint16_t)HandlePtr->DynamicHdlPtr->Ta + 
    		  (uint16_t)HandlePtr->DynamicHdlPtr->Tb))>>1;
  
  HandlePtr->DynamicHdlPtr->V_TA2 = HandlePtr->DynamicHdlPtr->V_TA - \
      HandlePtr->DynamicHdlPtr->Tb2;
  HandlePtr->DynamicHdlPtr->V_TB2 = HandlePtr->DynamicHdlPtr->V_TB + \
      HandlePtr->DynamicHdlPtr->Ta2 ;

  /* Update the compare register values based on the sector number */
  PWMSVM01_lUpdateDcLinkComRes (HandlePtr);
  /* Update the compare register values based on the sector number */
  switch (SVMPtr->Sector & 7U)
  {
    case 0:
      HandlePtr->PhasePtr[0]->CR1S = (uint32_t)SVMPtr->V_TB;
      HandlePtr->PhasePtr[0]->CR2S = (uint32_t)SVMPtr->V_TB2;
  
      HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
      HandlePtr->PhasePtr[1]->CR2S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
  
      HandlePtr->PhasePtr[2]->CR1S = (uint32_t)SVMPtr->V_TA;
      HandlePtr->PhasePtr[2]->CR2S = (uint32_t)SVMPtr->V_TA2;
      break;
    case 1:
      HandlePtr->PhasePtr[0]->CR1S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
      HandlePtr->PhasePtr[0]->CR2S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
  
      HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TB;
      HandlePtr->PhasePtr[1]->CR2S = (uint32_t)SVMPtr->V_TB2;
  
      HandlePtr->PhasePtr[2]->CR1S = (uint32_t)SVMPtr->V_TA;
      HandlePtr->PhasePtr[2]->CR2S = (uint32_t)SVMPtr->V_TA2;
      break;
    case 2:
      HandlePtr->PhasePtr[0]->CR1S = (uint32_t)SVMPtr->V_TA;
      HandlePtr->PhasePtr[0]->CR2S = (uint32_t)SVMPtr->V_TA2;
  
      HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TB;
      HandlePtr->PhasePtr[1]->CR2S = (uint32_t)SVMPtr->V_TB2;
  
      HandlePtr->PhasePtr[2]->CR1S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
      HandlePtr->PhasePtr[2]->CR2S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
      break;
    case 3:
      HandlePtr->PhasePtr[0]->CR1S = (uint32_t)SVMPtr->V_TA;
      HandlePtr->PhasePtr[0]->CR2S = (uint32_t)SVMPtr->V_TA2;
  
      HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
      HandlePtr->PhasePtr[1]->CR2S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
  
      HandlePtr->PhasePtr[2]->CR1S = (uint32_t)SVMPtr->V_TB;
      HandlePtr->PhasePtr[2]->CR2S = (uint32_t)SVMPtr->V_TB2;
      break;
    case 4:
      HandlePtr->PhasePtr[0]->CR1S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
      HandlePtr->PhasePtr[0]->CR2S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
  
      HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TA;
      HandlePtr->PhasePtr[1]->CR2S = (uint32_t)SVMPtr->V_TA2;
  
      HandlePtr->PhasePtr[2]->CR1S = (uint32_t)SVMPtr->V_TB;
      HandlePtr->PhasePtr[2]->CR2S = (uint32_t)SVMPtr->V_TB2;
      break;
    default:
      HandlePtr->PhasePtr[0]->CR1S = (uint32_t)SVMPtr->V_TB;
      HandlePtr->PhasePtr[0]->CR2S = (uint32_t)SVMPtr->V_TB2;
  
      HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TA;
      HandlePtr->PhasePtr[1]->CR2S = (uint32_t)SVMPtr->V_TA2;
  
      HandlePtr->PhasePtr[2]->CR1S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
      HandlePtr->PhasePtr[2]->CR2S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
      break;

  } 
  
}

/**
 * This function calculates the CCU8 slice compare value
 * for Asymmetric 5-segment SVM.
 */
static void PWMSVM01_lCalCmpValueAsym5(const PWMSVM01_HandleType* HandlePtr)
{
  PWMSVM01_DynamicHandleType* SVMPtr = HandlePtr->DynamicHdlPtr;
  
  /* check if Ta or Tb is not less than Tmin*/
  if (SVMPtr->Ta < HandlePtr->kTmin)
  {
    SVMPtr->Ta = 2U * (SVMPtr->Ta);
    if (SVMPtr->Ta < HandlePtr->kTmin)
    {
      SVMPtr->Ta = HandlePtr->kTmin;
    }
    SVMPtr->Ta2 = SVMPtr->Ta;
  }
   else
   {
    SVMPtr->Ta2=0U;
   }
   /*  5 -Segment Tb value Calcuation */
   if (SVMPtr->Tb < HandlePtr->kTmin)
   {
    SVMPtr->Tb = HandlePtr->kTmin;
   }
  HandlePtr->DynamicHdlPtr->V_TA = HandlePtr->kPeriod + 1U;
  HandlePtr->DynamicHdlPtr->V_TB = (HandlePtr->kPeriod - \
      HandlePtr->DynamicHdlPtr->Ta) - HandlePtr->DynamicHdlPtr->Tb;

  HandlePtr->DynamicHdlPtr->V_TA2 = HandlePtr->DynamicHdlPtr->V_TA;
  HandlePtr->DynamicHdlPtr->V_TB2 = HandlePtr->DynamicHdlPtr->V_TB  + \
      HandlePtr->DynamicHdlPtr->Ta2;

  /* Update the compare register values based on the sector number */
  /* DC link current measurement */
  PWMSVM01_lUpdateDcLinkComRes (HandlePtr);
  /* Update the compare register values based on the sector number */
  switch (SVMPtr->Sector & 7U)
  {
    case 0:
      HandlePtr->PhasePtr[0]->CR1S = (uint32_t)SVMPtr->V_TB;
      HandlePtr->PhasePtr[0]->CR2S = (uint32_t)SVMPtr->V_TB2;
  
      HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
      HandlePtr->PhasePtr[1]->CR2S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
  
      HandlePtr->PhasePtr[2]->CR1S = (uint32_t)SVMPtr->V_TA;
      HandlePtr->PhasePtr[2]->CR2S = (uint32_t)SVMPtr->V_TA2;
      break;
    case 1:
      HandlePtr->PhasePtr[0]->CR1S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
      HandlePtr->PhasePtr[0]->CR2S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
  
      HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TB;
      HandlePtr->PhasePtr[1]->CR2S = (uint32_t)SVMPtr->V_TB2;
  
      HandlePtr->PhasePtr[2]->CR1S = (uint32_t)SVMPtr->V_TA;
      HandlePtr->PhasePtr[2]->CR2S = (uint32_t)SVMPtr->V_TA2;
      break;
    case 2:
      HandlePtr->PhasePtr[0]->CR1S = (uint32_t)SVMPtr->V_TA;
      HandlePtr->PhasePtr[0]->CR2S = (uint32_t)SVMPtr->V_TA2;
  
      HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TB;
      HandlePtr->PhasePtr[1]->CR2S = (uint32_t)SVMPtr->V_TB2;
  
      HandlePtr->PhasePtr[2]->CR1S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
      HandlePtr->PhasePtr[2]->CR2S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
      break;
    case 3:
      HandlePtr->PhasePtr[0]->CR1S = (uint32_t)SVMPtr->V_TA;
      HandlePtr->PhasePtr[0]->CR2S = (uint32_t)SVMPtr->V_TA2;
  
      HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
      HandlePtr->PhasePtr[1]->CR2S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
  
      HandlePtr->PhasePtr[2]->CR1S = (uint32_t)SVMPtr->V_TB;
      HandlePtr->PhasePtr[2]->CR2S = (uint32_t)SVMPtr->V_TB2;
      break;
    case 4:
      HandlePtr->PhasePtr[0]->CR1S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
      HandlePtr->PhasePtr[0]->CR2S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
  
      HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TA;
      HandlePtr->PhasePtr[1]->CR2S = (uint32_t)SVMPtr->V_TA2;
  
      HandlePtr->PhasePtr[2]->CR1S = (uint32_t)SVMPtr->V_TB;
      HandlePtr->PhasePtr[2]->CR2S = (uint32_t)SVMPtr->V_TB2;
      break;
    default:
      HandlePtr->PhasePtr[0]->CR1S = (uint32_t)SVMPtr->V_TB;
      HandlePtr->PhasePtr[0]->CR2S = (uint32_t)SVMPtr->V_TB2;
  
      HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TA;
      HandlePtr->PhasePtr[1]->CR2S = (uint32_t)SVMPtr->V_TA2;
  
      HandlePtr->PhasePtr[2]->CR1S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
      HandlePtr->PhasePtr[2]->CR2S = (uint32_t)SVMPtr->V_TB + (uint32_t)SVMPtr->Ta;
      break;
  }

  
}
/**
 * This function calculates the CCU8 slice compare value
 * for Asymmetric 5-segment of Pseudo zero vector SVM mode.
 */
static void PWMSVM01_lCalc3av5segmentCompVal(const PWMSVM01_HandleType* HandlePtr)
{
  PWMSVM01_DynamicHandleType* SVMPtr = HandlePtr->DynamicHdlPtr;
  

  if (SVMPtr->SubSector == (uint32_t)0)
  {
    SVMPtr->Tb = SVMPtr->Tb + HandlePtr->kTmin;
     
    SVMPtr->V_TB2 = (HandlePtr->kPeriod-
      (SVMPtr->Ta + SVMPtr->Tb + HandlePtr->kTmin));
    SVMPtr->V_TB = (SVMPtr->V_TB2)>>1U;
    SVMPtr->V_TA = HandlePtr->kPeriod;
    SVMPtr->V_TC = SVMPtr->V_TB+HandlePtr->kTmin;
  }
  else
  {
    SVMPtr->Ta = SVMPtr->Ta + HandlePtr->kTmin;
     
    SVMPtr->V_TB2 = (HandlePtr->kPeriod -
      (SVMPtr->Ta + SVMPtr->Tb + HandlePtr->kTmin));
    SVMPtr->V_TB = (SVMPtr->V_TB2)>>1;
    SVMPtr->V_TA = HandlePtr->kPeriod;

    SVMPtr->V_TC = SVMPtr->V_TB;
  }  
  if (HandlePtr->kExtTriggerCMType == (uint8_t)PWMSVM01_DCLINKCM) 
  {
    HandlePtr->CurrentTriggerPtr->CR1S =(uint32_t)SVMPtr->V_TA -
    		((uint32_t)SVMPtr->Ta + ((uint32_t)SVMPtr->Tb>>1));
    HandlePtr->CurrentTriggerPtr->CR2S =(uint32_t)SVMPtr->V_TA -
    		((uint32_t)SVMPtr->Ta>>1);
  }
  switch (SVMPtr->Sector & 7U)
  {
    case 0:
       HandlePtr->PhasePtr[0]->CR1S = (uint32_t)SVMPtr->V_TB+HandlePtr->kTmin;
       HandlePtr->PhasePtr[0]->CR2S = (uint32_t)SVMPtr->V_TA;
  
       HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TC;
       HandlePtr->PhasePtr[1]->CR2S = (uint32_t)SVMPtr->V_TA - SVMPtr->Ta;
  
       HandlePtr->PhasePtr[2]->CR1S = (uint32_t)SVMPtr->V_TB;
       HandlePtr->PhasePtr[2]->CR2S = (uint32_t)SVMPtr->V_TB2+HandlePtr->kTmin;
       break;
    case 1:
       HandlePtr->PhasePtr[0]->CR1S =SVMPtr->V_TC;
       HandlePtr->PhasePtr[0]->CR2S = (uint32_t)SVMPtr->V_TA-SVMPtr->Ta;

       HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TB+HandlePtr->kTmin;
       HandlePtr->PhasePtr[1]->CR2S = (uint32_t)SVMPtr->V_TA;

       HandlePtr->PhasePtr[2]->CR1S = (uint32_t)SVMPtr->V_TB;
       HandlePtr->PhasePtr[2]->CR2S = (uint32_t)SVMPtr->V_TB2+HandlePtr->kTmin;
       break;
    case 2:
       HandlePtr->PhasePtr[0]->CR1S = (uint32_t)SVMPtr->V_TB;
       HandlePtr->PhasePtr[0]->CR2S = (uint32_t)SVMPtr->V_TB2+HandlePtr->kTmin;
  
       HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TB+HandlePtr->kTmin;
       HandlePtr->PhasePtr[1]->CR2S = (uint32_t)SVMPtr->V_TA;
  
       HandlePtr->PhasePtr[2]->CR1S = SVMPtr->V_TC;
       HandlePtr->PhasePtr[2]->CR2S = (uint32_t)SVMPtr->V_TA-SVMPtr->Ta;
       break;
    case 3:
       HandlePtr->PhasePtr[0]->CR1S = (uint32_t)SVMPtr->V_TB;
       HandlePtr->PhasePtr[0]->CR2S = (uint32_t)SVMPtr->V_TB2+HandlePtr->kTmin;

       HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TC;
       HandlePtr->PhasePtr[1]->CR2S = (uint32_t)SVMPtr->V_TA-SVMPtr->Ta;

       HandlePtr->PhasePtr[2]->CR1S = (uint32_t)SVMPtr->V_TB+HandlePtr->kTmin;
       HandlePtr->PhasePtr[2]->CR2S = (uint32_t)SVMPtr->V_TA;
       break;
    case 4:
       HandlePtr->PhasePtr[0]->CR1S = (uint32_t)SVMPtr->V_TC;
       HandlePtr->PhasePtr[0]->CR2S = (uint32_t)SVMPtr->V_TA-SVMPtr->Ta;
  
       HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TB;
       HandlePtr->PhasePtr[1]->CR2S = (uint32_t)SVMPtr->V_TB2+HandlePtr->kTmin;
  
       HandlePtr->PhasePtr[2]->CR1S = (uint32_t)SVMPtr->V_TB+HandlePtr->kTmin;
       HandlePtr->PhasePtr[2]->CR2S = (uint32_t)SVMPtr->V_TA;
       break;
    default:
       HandlePtr->PhasePtr[0]->CR1S = (uint32_t)SVMPtr->V_TB+HandlePtr->kTmin;
       HandlePtr->PhasePtr[0]->CR2S = (uint32_t)SVMPtr->V_TA;

       HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TB;
       HandlePtr->PhasePtr[1]->CR2S = (uint32_t)SVMPtr->V_TB2+HandlePtr->kTmin;

       HandlePtr->PhasePtr[2]->CR1S = (uint32_t)SVMPtr->V_TC;
       HandlePtr->PhasePtr[2]->CR2S = (uint32_t)SVMPtr->V_TA-SVMPtr->Ta;
       break;
    }
  
  
}
/**
 * This function calculates the CCU8 slice compare value
 * for Asymmetric 7-segment of Pseudo zero vector SVM mode.
 */
static void PWMSVM01_lCalc4av7segmentCompVal(const PWMSVM01_HandleType* HandlePtr)
{
  PWMSVM01_DynamicHandleType* SVMPtr = HandlePtr->DynamicHdlPtr;
  
  
  
  HandlePtr->DynamicHdlPtr->Ta= HandlePtr->DynamicHdlPtr->Ta+HandlePtr->kTmin;
  HandlePtr->DynamicHdlPtr->Tb= HandlePtr->DynamicHdlPtr->Tb+HandlePtr->kTmin;
  
  SVMPtr->V_TB2 = (uint16_t)((uint16_t)HandlePtr->kPeriod- \
		  ((uint16_t)HandlePtr->DynamicHdlPtr->Ta +\
                (uint16_t)HandlePtr->DynamicHdlPtr->Tb +
                (2U*HandlePtr->kTmin)));
  
  SVMPtr->V_TB = (uint16_t)HandlePtr->DynamicHdlPtr->V_TB2>>2U;
  SVMPtr->V_TA2= (uint16_t)SVMPtr->V_TB2+(2U*HandlePtr->kTmin);
  SVMPtr->V_TA = (uint16_t)HandlePtr->kPeriod-(uint16_t)SVMPtr->V_TB;

  if (HandlePtr->kExtTriggerCMType == (uint8_t)PWMSVM01_DCLINKCM) 
  {
    HandlePtr->CurrentTriggerPtr->CR1S =(uint32_t)SVMPtr->V_TA - \
    		((uint32_t)(SVMPtr->Ta) + ((uint32_t)SVMPtr->Tb>>1));
    HandlePtr->CurrentTriggerPtr->CR2S =(uint32_t)SVMPtr->V_TA - \
    		((uint32_t)SVMPtr->Ta>>1);
  }
  switch (SVMPtr->Sector & 7U)
  {
    case 0:
      HandlePtr->PhasePtr[0]->CR1S = (uint32_t)SVMPtr->V_TB + ((uint32_t)2*HandlePtr->kTmin);
      HandlePtr->PhasePtr[0]->CR2S = (uint32_t)SVMPtr->V_TA;
  
      HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TB + HandlePtr->kTmin;
      HandlePtr->PhasePtr[1]->CR2S = (uint32_t)SVMPtr->V_TA - SVMPtr->Ta;
  
      HandlePtr->PhasePtr[2]->CR1S = (uint32_t)SVMPtr->V_TB;
      HandlePtr->PhasePtr[2]->CR2S = (uint32_t)SVMPtr->V_TA2 - SVMPtr->V_TB;
      break;
    case 1:
      HandlePtr->PhasePtr[0]->CR1S = (uint32_t)SVMPtr->V_TB+HandlePtr->kTmin;
      HandlePtr->PhasePtr[0]->CR2S = (uint32_t)SVMPtr->V_TA - SVMPtr->Ta;
  
      HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TB + ((uint32_t)2*HandlePtr->kTmin);
      HandlePtr->PhasePtr[1]->CR2S = (uint32_t)SVMPtr->V_TA;
  
      HandlePtr->PhasePtr[2]->CR1S = (uint32_t)SVMPtr->V_TB;
      HandlePtr->PhasePtr[2]->CR2S = (uint32_t)SVMPtr->V_TA2 - SVMPtr->V_TB;
      break;
    case 2:
      HandlePtr->PhasePtr[0]->CR1S = (uint32_t)SVMPtr->V_TB;
      HandlePtr->PhasePtr[0]->CR2S = (uint32_t)SVMPtr->V_TA2 - SVMPtr->V_TB;
  
      HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TB + ((uint32_t)2*HandlePtr->kTmin);
      HandlePtr->PhasePtr[1]->CR2S = (uint32_t)SVMPtr->V_TA;
  
      HandlePtr->PhasePtr[2]->CR1S = (uint32_t)SVMPtr->V_TB + HandlePtr->kTmin;
      HandlePtr->PhasePtr[2]->CR2S = (uint32_t)SVMPtr->V_TA - SVMPtr->Ta;
      break;
    case 3:
      HandlePtr->PhasePtr[0]->CR1S = (uint32_t)SVMPtr->V_TB;
      HandlePtr->PhasePtr[0]->CR2S = (uint32_t)SVMPtr->V_TA2 - (uint32_t)SVMPtr->V_TB;
  
      HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TB + HandlePtr->kTmin;
      HandlePtr->PhasePtr[1]->CR2S = (uint32_t)SVMPtr->V_TA - (uint32_t)SVMPtr->Ta;
  
      HandlePtr->PhasePtr[2]->CR1S = (uint32_t)SVMPtr->V_TB + ((uint32_t)2*HandlePtr->kTmin);
      HandlePtr->PhasePtr[2]->CR2S = (uint32_t)SVMPtr->V_TA;
      break;
    case 4:
      HandlePtr->PhasePtr[0]->CR1S = (uint32_t)SVMPtr->V_TB + (uint32_t)HandlePtr->kTmin;
      HandlePtr->PhasePtr[0]->CR2S = (uint32_t)SVMPtr->V_TA - (uint32_t)SVMPtr->Ta;
  
      HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TB;
      HandlePtr->PhasePtr[1]->CR2S = (uint32_t)SVMPtr->V_TA2-(uint32_t)SVMPtr->V_TB;
  
      HandlePtr->PhasePtr[2]->CR1S = (uint32_t)SVMPtr->V_TB + ((uint32_t)2*HandlePtr->kTmin);
      HandlePtr->PhasePtr[2]->CR2S = (uint32_t)SVMPtr->V_TA;
      break;
    default:
      HandlePtr->PhasePtr[0]->CR1S = (uint32_t)SVMPtr->V_TB + ((uint32_t)2*HandlePtr->kTmin);
      HandlePtr->PhasePtr[0]->CR2S = (uint32_t)SVMPtr->V_TA;
  
      HandlePtr->PhasePtr[1]->CR1S = (uint32_t)SVMPtr->V_TB;
      HandlePtr->PhasePtr[1]->CR2S = (uint32_t)SVMPtr->V_TA2 - (uint32_t)SVMPtr->V_TB;
  
      HandlePtr->PhasePtr[2]->CR1S = (uint32_t)SVMPtr->V_TB + (uint32_t)HandlePtr->kTmin;
      HandlePtr->PhasePtr[2]->CR2S = (uint32_t)SVMPtr->V_TA -(uint32_t)SVMPtr->Ta;
      break;
  }
  
}

#if (UC_FAMILY == XMC1)
/*
 * SVM Segment Time calculation using CORDIC
 */
void PWMSVM01_lTimecalcUsingCORDIC
(
		const PWMSVM01_HandleType* HandlePtr,
		uint16_t Amplitude,
		uint16_t Angle
		)
{
  int32_t  CosxAmp;
  int32_t  SinxAmp;
  uint32_t Tacord_Tmp;
  uint32_t Tbcord_Tmp;
  uint32_t Sectortheta;
  uint32_t Transtheta;
  HandlePtr->DynamicHdlPtr->Sector = (uint16_t)(((Angle * 6U) >> 16U) & 7U);
  /*calculate sector angle*/
  Sectortheta = \
    (uint32_t)(Angle-(HandlePtr->DynamicHdlPtr->Sector*PWMSVM01_SIXTYDEG));
  Transtheta = (uint32_t)(Sectortheta>>1);
  if (Transtheta<=PWMSVM01_THIRTYDEG)
  {
    HandlePtr->DynamicHdlPtr->SubSector = 0;
  }
  else
  {
    HandlePtr->DynamicHdlPtr->SubSector = 1;
  }

  /*Clearing previous values of CORDX,CORDY and CORDZ Registers*/
  MATH->STATC = 0;

  /* Set CORDIC to Circular Operating Mode and Rotation Mode,
   * Auto start of calculation after write access to X parameter data register,
   * X result data format to Unsigned, when read,
   * After the last iteration of calculation the X & Y values are divided by 1
   */
  MATH->CON = 0x2A;

  /*Input sector angle*/
  MATH->CORDZ= \
  (uint32_t)(Sectortheta <<((uint32_t)PWMSVM01_ANGLESCALE+MATH_CORDZ_DATA_Pos));

  /* Set the Y value to zero*/
  WR_REG(MATH->CORDY, MATH_CORDY_DATA_Msk, \
               MATH_CORDY_DATA_Pos, 0);

  /*Load the amplitude value */
  WR_REG(MATH->CORDX, MATH_CORDX_DATA_Msk, \
                       MATH_CORDX_DATA_Pos, Amplitude);

  /*Checking busy status of CORDIC calculation*/
  while(MATH->STATC & 0x1);

  /*Reading cordic X result which is costheta X amplitude*/
  CosxAmp = MATH->CORRX >>MATH_CORDX_DATA_Pos;

  /*Reading cordic Y result which is sintheta X amplitude*/
  SinxAmp = MATH->CORRY>>MATH_CORDY_DATA_Pos;

  if ((HandlePtr->DynamicHdlPtr->Sector & 1U)==1U)
  {
    /* Multiply Result value with sinscale to eliminate gain factor K*/
    Tacord_Tmp = (int32_t)(SinxAmp*PWMSVM01_KSINSCALE);
    HandlePtr->DynamicHdlPtr->Ta = (uint16_t)(Tacord_Tmp>>14U);
    /* Multiply Result value with cosscale to eliminate gain factor K*
     * sin(60-Angle) = (Sqrt(3)*cos(angle) - sin(angle))/2
     */
    Tbcord_Tmp = (int32_t)((CosxAmp*PWMSVM01_KCOSSCALE) - Tacord_Tmp);
    HandlePtr->DynamicHdlPtr->Tb = (uint16_t)(Tbcord_Tmp>>15U);
  }
  else
  {
    /* Multiply Result value with sinscale to eliminate gain factor K*/
    Tbcord_Tmp = (int32_t)(SinxAmp*PWMSVM01_KSINSCALE);
    HandlePtr->DynamicHdlPtr->Tb = (uint16_t)(Tbcord_Tmp>>14U);
    /* Multiply Result value with cosscale to eliminate gain factor K*
     * sin(60-Angle) = (Sqrt(3)*cos(angle) - sin(angle))/2
     */
    Tacord_Tmp = (int32_t)((CosxAmp*PWMSVM01_KCOSSCALE) - Tbcord_Tmp);
	  HandlePtr->DynamicHdlPtr->Ta = (uint16_t)(Tacord_Tmp>>15U);
  }

  /* If Ta and Tb values are less then zero, reset these values to zero */
  if (HandlePtr->DynamicHdlPtr->Ta >HandlePtr->kPeriod)
  {
	  HandlePtr->DynamicHdlPtr->Ta=0;
  }
  if (HandlePtr->DynamicHdlPtr->Tb >HandlePtr->kPeriod)
  {
	  HandlePtr->DynamicHdlPtr->Tb=0;
  }

}
#endif
/*
 * SVM Segment Time calculation using Look up table
 */
void PWMSVM01_lTimecalcUsingLUT
(
		const PWMSVM01_HandleType* HandlePtr,
		uint16_t Amplitude,
		uint16_t Angle
		)
{
  uint16_t AngleTemp;
  uint16_t SectorAngle;
  uint16_t TransAngle;
  AngleTemp = (uint16_t)(Angle >> 6U) * 6U;
  SectorAngle = (uint16_t)(AngleTemp & (uint16_t)0x003FF);
  HandlePtr->DynamicHdlPtr->Sector =
      (uint16_t) ((AngleTemp>>10U) & 7U);
  TransAngle = (uint16_t)SectorAngle & (uint16_t)0xFF;
  /*0x7F refers to thirty degree where as 0xFF refers to 60 degree*/
  if (TransAngle <= (uint16_t)0x7F)
  {
    HandlePtr->DynamicHdlPtr->SubSector = 0U;
  }
  else
  {
    HandlePtr->DynamicHdlPtr->SubSector = 1U;
  }
  if ((HandlePtr->DynamicHdlPtr->Sector & 1U)==1U)
  {
    HandlePtr->DynamicHdlPtr->Tb =
      PWMSVM01_MulQ15(Amplitude, Sinus60_tab[1023U-SectorAngle], 15U);
    HandlePtr->DynamicHdlPtr->Ta =
      PWMSVM01_MulQ15(Amplitude, Sinus60_tab[SectorAngle], 15U);
  }
  else
  {
    HandlePtr->DynamicHdlPtr->Ta =
      PWMSVM01_MulQ15(Amplitude, Sinus60_tab[1023U-SectorAngle], 15U);
    HandlePtr->DynamicHdlPtr->Tb =
      PWMSVM01_MulQ15(Amplitude, Sinus60_tab[SectorAngle], 15U);
  }
}
/*******************************************************************************
**                      Public Function Definitions                           **
*******************************************************************************/
/**
 * This function initializes the peripherals and SVM structure 
 * required for the SVM algorithm.
 */
void PWMSVM01_Init(void)
{
  uint32_t Count;
   

  /*Clock initialization - if it is not already done by DAVE3.h */
  #if (UC_FAMILY == XMC1)
    CLK002_Init();
  #else
    CLK001_Init();
  #endif 
  /* CCU8 global init to start the prescalar and de-assert the module */
  CCU8GLOBAL_Init();

  /* Initialise PWMSVM01 Handle */	
  for (Count = 0U; Count < PWMSVM01_NUM_INSTANCES; Count++)
  {
    PWMSVM01_lInit(PWMSVM01_HandleArray[Count]);
  }
  
    
}

/**
 * This function starts the CCU8 slices used to generate SVM.
 */
void PWMSVM01_Start(const PWMSVM01_HandleType* HandlePtr)
{
  IO004_HandleType IOHandle = *(HandlePtr->InverterPinPtr);  
    
  
  if ((HandlePtr->DynamicHdlPtr->State == PWMSVM01_INITIALIZED) ||
    (HandlePtr->DynamicHdlPtr->State == PWMSVM01_STOPPED))
  {  
    HandlePtr->DynamicHdlPtr->Ta = 0U;
    HandlePtr->DynamicHdlPtr->Tb = 0U;
    HandlePtr->DynamicHdlPtr->Ta2 = 0U;
    HandlePtr->DynamicHdlPtr->Tb2 = 0U;
    HandlePtr->DynamicHdlPtr->V_TA = 0U;
    HandlePtr->DynamicHdlPtr->V_TB = 0U;
    HandlePtr->DynamicHdlPtr->V_TA2 = 0U;
    HandlePtr->DynamicHdlPtr->V_TB2 = 0U;
    HandlePtr->DynamicHdlPtr->Sector = 0U;
  
    /*Enable the slice 0 period match interrupt */
    HandlePtr->PhasePtr[0]->INTE  |= 
      ((uint32_t)HandlePtr->kEnableTrapInterrupt << CCU8_CC8_INTE_E2AE_Pos)
	    | HandlePtr->kEnablePerMatch;
    /*Enable the inverter pin */
    if (HandlePtr->kInverterPin == 1U)
    {
      IO004_SetPin(IOHandle);
    }
    else
    {
      IO004_ResetPin(IOHandle);
    }
    HandlePtr->GlobalPtr->GIDLC  |= (uint32_t)0x10F;
    /* if trap is enabled, Enable Trap for all the three phases
    map the external trap functionality to event 2 */
    if (HandlePtr->kEnableTrap == 1U)
    {
      HandlePtr->PhasePtr[0]->CMC |= (uint32_t)0x20000;
      HandlePtr->PhasePtr[1]->CMC |= (uint32_t)0x20000;
      HandlePtr->PhasePtr[2]->CMC |= (uint32_t)0x20000;
    }
    if (HandlePtr->kExtTriggerCMType == (uint8_t)PWMSVM01_DCLINKCM)
    {
      HandlePtr->PhasePtr[0]->TIMER = ((uint32_t)HandlePtr->kTmin>>1);
      HandlePtr->PhasePtr[1]->TIMER = ((uint32_t)HandlePtr->kTmin>>1);
      HandlePtr->PhasePtr[2]->TIMER = ((uint32_t)HandlePtr->kTmin>>1);
    }
    else if (HandlePtr->kExtTriggerCMType == (uint8_t)PWMSVM01_PHASECM )
    {
      HandlePtr->PhasePtr[0]->TIMER =
       (((uint32_t)HandlePtr->kDeadTime>>8U) & (uint32_t)0xFF);
      HandlePtr->PhasePtr[1]->TIMER =
        (((uint32_t)HandlePtr->kDeadTime>>8U) & (uint32_t)0xFF);
      HandlePtr->PhasePtr[2]->TIMER =
        (((uint32_t)HandlePtr->kDeadTime>>8U) & (uint32_t)0xFF);
    }
	else
    {
      /* synchronous start of all the three phases */
      SCU_GENERAL->CCUCON |= (uint32_t)(HandlePtr->kSyncStart);
    }
    /* synchronous start of all the three phases */
    SCU_GENERAL->CCUCON |= (uint32_t)(HandlePtr->kSyncStart);
    HandlePtr->DynamicHdlPtr->State = PWMSVM01_RUNNING;
  }    
}

/**
 * This function stops the CCU8 slices used to generate SVM.
 */
void PWMSVM01_Stop(const PWMSVM01_HandleType* HandlePtr)
{
  IO004_HandleType IOHandle = *(HandlePtr->InverterPinPtr);  
  uint32_t Index;
      
  /*Inverter Enable pin level is set to passive level.*/
 if (HandlePtr->kInverterPin == 2U)
  {
    IO004_SetPin(IOHandle);
  }
  else 
  {
    IO004_ResetPin(IOHandle);
  }
  /* Disable Trap for all the three phases */
  if (HandlePtr->kEnableTrap == 1U)
  {
    HandlePtr->PhasePtr[0]->CMC &= ~((uint32_t)0x20000);
    HandlePtr->PhasePtr[1]->CMC &= ~((uint32_t)0x20000);
    HandlePtr->PhasePtr[2]->CMC &= ~((uint32_t)0x20000);
  }
  /*Disable the slice 0 period match interrupt */
  HandlePtr->PhasePtr[0]->INTE  &=
		  ~(((uint32_t)HandlePtr->kEnableTrapInterrupt << 10) |
				  (uint32_t)HandlePtr->kEnablePerMatch);
  /* stop all three phases */
  for (Index = 0U; Index < PWMSVM01_NUMBERPHASE; Index++)
  {
    HandlePtr->PhasePtr[Index]->TCCLR = (uint32_t)0xF;
  }
  if (HandlePtr->kTriggerControl == (uint8_t)PWMSVM01_HWTRIGGER)
  {
    HandlePtr->CurrentTriggerPtr->TCCLR = (uint32_t)0xF;
  }
  SCU_GENERAL->CCUCON &= ~((uint32_t)HandlePtr->kSyncStart);

  HandlePtr->DynamicHdlPtr->State = PWMSVM01_STOPPED;
  
    
}

/* This function resets all the registers. */
void PWMSVM01_Deinit(const PWMSVM01_HandleType* HandlePtr)
{
  uint32_t Index;
  IO004_HandleType IOHandle = *(HandlePtr->InverterPinPtr);  
    
  /*Inverter Enable pin level is set to passive level.*/
 if ( HandlePtr->kInverterPin == 2U )
  {
    IO004_SetPin(IOHandle);
  }
  else 
  {
    IO004_ResetPin(IOHandle);
  }
  for (Index = 0U; Index < PWMSVM01_NUMBERPHASE ; Index++)
  {
    HandlePtr->PhasePtr[Index]->PRS = 0U;
    HandlePtr->PhasePtr[Index]->CHC = 0U;
    HandlePtr->PhasePtr[Index]->CR1S = 0U;
    HandlePtr->PhasePtr[Index]->CR2S = 0U;
    HandlePtr->PhasePtr[Index]->DTC = 0U;
    HandlePtr->PhasePtr[Index]->PSL = 0U;
    HandlePtr->PhasePtr[Index]->DC1R = 0U;
    HandlePtr->PhasePtr[Index]->TC = 0U;
    HandlePtr->PhasePtr[Index]->INS = 0U;
    HandlePtr->PhasePtr[Index]->CMC = 0U;
  }
  if (HandlePtr->kTriggerControl == (uint8_t)PWMSVM01_HWTRIGGER)
  {
    HandlePtr->CurrentTriggerPtr->PRS = 0U;
    HandlePtr->CurrentTriggerPtr->CHC = 0U;
    HandlePtr->CurrentTriggerPtr->CR1S = 0U;
    HandlePtr->CurrentTriggerPtr->CR2S = 0U;
    HandlePtr->CurrentTriggerPtr->DTC = 0U;
    HandlePtr->CurrentTriggerPtr->PSL = 0U;
    HandlePtr->CurrentTriggerPtr->DC1R = 0U;
    HandlePtr->CurrentTriggerPtr->TC = 0U;
    HandlePtr->CurrentTriggerPtr->INS = 0U;
    HandlePtr->CurrentTriggerPtr->CMC = 0U;
    HandlePtr->GlobalPtr->GCSS |=
    		(uint32_t) ((uint32_t)1 << 
    				((uint32_t)4*HandlePtr->kCurrentTrigSliceNo));
  }
  /* Enable the shadow transfer for all three slices */
  HandlePtr->GlobalPtr->GCSS  |= 
		  (uint32_t)(((uint32_t)1 << ((uint32_t)4*HandlePtr->kPhWSliceNo))
        | ((uint32_t)1 << ((uint32_t)4 * HandlePtr->kPhVSliceNo))
        | ((uint32_t)1 << ((uint32_t)4 * HandlePtr->kPhUSliceNo)));
  HandlePtr->DynamicHdlPtr->State = PWMSVM01_UNINITIALIZED;
    
}
/**
 * This is the SVM algorithm for sinusoidal commutation.
 * It updates the compare registers of the CCU8 slices as per calculated
 * duty cycle.
 */
void PWMSVM01_SVM
(
    const PWMSVM01_HandleType* HandlePtr,
    uint16_t Amplitude,
    uint16_t Angle
)
{
  
  if (Amplitude > (HandlePtr->kMaxAmplitude))
  {
    Amplitude = HandlePtr->kMaxAmplitude;
    DBG002_WARNING(APP_GID, (uint8_t)PWMSVM01_INVALID_PARAM, 0U, (uint8_t*) NULL);
  }
  #if (UC_FAMILY == XMC1)
    if (HandlePtr->kSegTimeCalc == PWMSVM01_USE_CORDIC)
    {
      PWMSVM01_lTimecalcUsingCORDIC(HandlePtr,Amplitude,Angle);
    }
    else
    {
	  PWMSVM01_lTimecalcUsingLUT(HandlePtr,Amplitude,Angle);
    }
  #else
  PWMSVM01_lTimecalcUsingLUT(HandlePtr,Amplitude,Angle);
  #endif

  /*This function calculates and updates compare values in compare register*/
  PWMSVM01_UpdateCmpValuePtr[HandlePtr->kSVMConfig](HandlePtr);
  /*Enable the shadow transfer for all three slice*/
  HandlePtr->GlobalPtr->GCSS  |= (uint32_t)HandlePtr->kShadowTransfer;
  
}

/**
 * This is the library function to multiply the two numbers that is param_1 and
 * param_2.Result of this multiplication is divided by 2^scale and return the
 * resultant.
 */
static uint16_t PWMSVM01_MulQ15(uint16_t Param1, uint16_t Param2, uint16_t Scale)
{
  
  return ((uint16_t)(((uint16_t)Param1 * Param2) >> Scale));  
  
}

/* This function resets the trap flag through software */
void PWMSVM01_ResetTrapFlag(const PWMSVM01_HandleType* HandlePtr)
{
  uint32_t Index;
    
  for (Index = 0U; Index <PWMSVM01_NUMBERPHASE; Index++)
  {
    if (HandlePtr->PhasePtr[Index] != NULL)
    {
      HandlePtr->PhasePtr[Index]->SWR |= ((uint32_t)1 << 11U);
    }
  }
    
}

/*This function enables the event for the specified phase*/
void PWMSVM01_EnableEvent
(
    const PWMSVM01_HandleType* HandlePtr, 
    uint8_t PhaseNo, 
    PWMSVM01_EventType Event
)
{   
  if ((HandlePtr->PhasePtr[PhaseNo] != NULL) && (PhaseNo < 4U))
  {
    HandlePtr->PhasePtr[PhaseNo]->INTE |= ((uint32_t)1 << (uint32_t)Event);
  }    
}

/*This function enables the event for the specified phase*/
void PWMSVM01_DisableEvent
(
    const PWMSVM01_HandleType* HandlePtr, 
    uint8_t PhaseNo, 
    PWMSVM01_EventType Event
)
{
  if ((HandlePtr->PhasePtr[PhaseNo] != NULL) && (PhaseNo < 4U))
  {
    HandlePtr->PhasePtr[PhaseNo]->INTE &= ~((uint32_t)1 << (uint32_t)Event);
  }    
}

/*This function sets the event for the specified phase*/
void PWMSVM01_SetPendingEvent
(
    const PWMSVM01_HandleType* HandlePtr, 
    uint8_t PhaseNo, 
    PWMSVM01_EventType Event
)
{
  if ((HandlePtr->PhasePtr[PhaseNo] != NULL) && (PhaseNo < 4U))
  {
    HandlePtr->PhasePtr[PhaseNo]->SWS |= ((uint32_t)1 << (uint32_t)Event);
  }    
}

/*This function clears the event for the specified phase*/
void PWMSVM01_ClearPendingEvent
(
    const PWMSVM01_HandleType* HandlePtr, 
    uint8_t PhaseNo, 
    PWMSVM01_EventType Event
)
{   
  if ((HandlePtr->PhasePtr[PhaseNo] != NULL) && (PhaseNo < 4U))
  {
    HandlePtr->PhasePtr[PhaseNo]->SWR |= ((uint32_t)1 << (uint32_t)Event);
  }    
}

/*This function checks if given event is set or reset*/
uint8_t PWMSVM01_GetPendingEvent
(
    const PWMSVM01_HandleType* HandlePtr, 
    uint8_t PhaseNo, 
    PWMSVM01_EventType Event
)
{
  uint8_t EvtStatus;
    
  if ((HandlePtr->PhasePtr[PhaseNo] != NULL) && (PhaseNo < 4U))
  {
    EvtStatus = (uint8_t)((HandlePtr->PhasePtr[PhaseNo]->INTS &
    		((uint32_t)1 << (uint32_t)Event)) >> (uint32_t)Event );
  }
  else
  {
    EvtStatus = (uint8_t)PWMSVM01_INVALID_PARAM;
  }
   
  return EvtStatus;
}

/**
 * @endcond
 */

