/**
 * @file PWMSVM01_Conf.c
 * @brief This file contains the configuration parameters for all instances of 
 * the PWMSVM01 App
 */

/**
 * @cond INTERNAL_DOCS
 */
/*******************************************************************************
**                           INCLUDE FILES                                     *
 ******************************************************************************/
/* Included header file*/
#include <DAVE3.h> 

    

/*******************************************************************************
 **                        PRIVATE MACRO DEFINITIONS                          **
 ******************************************************************************/

/*******************************************************************************
 **                        PRIVATE TYPE DEFINITIONS
 ******************************************************************************/

/*******************************************************************************
 **                       PRIVATE FUNCTION DECLARATIONS:
 ******************************************************************************/

/*******************************************************************************
 **                       PRIVATE CONSTANT DEFINITIONS:
 ******************************************************************************/

/*******************************************************************************
 **                       GLOBAL VARIABLE DEFINITIONS:
 ******************************************************************************/
PWMSVM01_DynamicHandleType PWMSVM01_DynamicHandle0 = 
{
  .Ta        = (uint16_t)0,
  .Tb        = (uint16_t)0,
  .Ta2       = (uint16_t)0,
  .Tb2       = (uint16_t)0,
  
  .V_TA      = (uint16_t)0,
  .V_TB      = (uint16_t)0,
  .V_TA2     = (uint16_t)0,
  .V_TB2     = (uint16_t)0,
  .V_TC      = (uint16_t)0, 
  .Sector    = (uint16_t)0,
  .SubSector = (uint16_t)0,
  .State     = PWMSVM01_UNINITIALIZED,
};

/*******************************************************************************
 **                       GLOBAL CONSTANT DEFINITIONS:                     
 ******************************************************************************/
const PWMSVM01_HandleType PWMSVM01_Handle0 = 
{
  .kEnablePerMatch = (uint8_t)1,
  .kEnableTrapInterrupt = (uint8_t)1,
  .kSVMConfig = (uint8_t)0x0, 
  .kAsymmetricPWM = (uint8_t)0,
  .kPassiveLevel = (uint8_t)0, 
  .kPrescaler = (uint8_t)0,  
  .kDeadTime = (uint16_t)0x2020,
  .kDeadTimePrescaler = (uint8_t)0,
  .kTmin = (uint16_t)0x42,
  .kSegTimeCalc =(uint8_t)PWMSVM01_USE_LOOKUPTABLE,
  .kPWMType=(uint8_t)PWMSVM01_STANDARD,
  .kPWMFrequency = (uint32_t)20000, 
  .kPeriod = (uint16_t)1599,  
  .kSyncStart = (uint16_t)0x100,    
  .kInverterPin = (uint8_t) 1,  
  .kEnableTrap = (uint8_t)1,  
  .kTrapSync= (uint8_t)0,
  .kTrapExitControl= (uint8_t)0,
  .kMaxAmplitude  = (uint16_t)1599,
  .kTrapLevel= (uint8_t)1,
  .InverterPinPtr =  &IO004_Handle0, 
  .GlobalPtr = (CCU8_GLOBAL_TypeDef*) CCU80_BASE,
  .PhasePtr  = {(CCU8_CC8_TypeDef*)CCU80_CC80,
           (CCU8_CC8_TypeDef*)CCU80_CC81,
           (CCU8_CC8_TypeDef*)CCU80_CC82},           
  .DynamicHdlPtr = &PWMSVM01_DynamicHandle0,
  .CurrentTriggerPtr = (CCU8_CC8_TypeDef*)CCU80_CC83,
  .Slice83Ptr = (CCU8_CC8_TypeDef*)CCU80_CC83,
  .kShadowTransfer = (uint16_t)0x1111,              
  .kECurrentMeasInt = (uint8_t)1,
  .kExtTriggerCMType =(uint8_t)PWMSVM01_DCLINKCM,  
  .kTriggerControl = (uint8_t)PWMSVM01_HWTRIGGER,
  .kPhWSliceNo = (uint32_t)2,
  .kPhVSliceNo = (uint32_t)1,
  .kPhUSliceNo = (uint32_t)0,
  .kCurrentTrigSliceNo = (uint32_t)3,
};
  

/* The variable is used to store the address of the Handles */
PWMSVM01_HandleType* PWMSVM01_HandleArray[PWMSVM01_NUM_INSTANCES] = 
{
  (PWMSVM01_HandleType*) &PWMSVM01_Handle0
};
/*******************************************************************************
 **                       PUBLIC FUNCTION DEFINITIONS:
 ******************************************************************************/

/*******************************************************************************
 **                       FUNCTION LIKE MACRO DEFINITIONS:
 ******************************************************************************/

/*******************************************************************************
 **                       PRIVATE VARIABLES:
 ******************************************************************************/

/*******************************************************************************
 **                       PRIVATE FUNCTION DEFINITIONS:
 ******************************************************************************/
/**
 * @endcond
 */
/*CODE_BLOCK_END*/

