/*
 * Main.c
 *
 *  Created on: Sep 13, 2016
 *      Author: Stefannn
 */



#include <DAVE3.h>			//Declarations from DAVE3 Code Generation (includes SFR declaration)

/* System Tick Timer register value */
#define TICKS_PER_SECOND 1000
#define SECONDS_PER_TICK (1.0F / (float)TICKS_PER_SECOND)

/* XSPY Constant definition */
#define NUMBER_VARIABLES_XSPY1		10	//31.10
#define NUMBER_VARIABLES_XSPY2		2	//31.10
#define NO_XSPY_APPS				2

/* Motor Parameters definition */
#define FORWARD_DIRECTION			1
#define REVERSE_DIRECTION			-1

//Speed = (calculate_Speed * Norminal_Speed) >> 15
//Speed_Scalling_Factor = (PMSMFOCSL01_Handle0.kNormSpeed >> 15) = 0.5086;
/* Private variables ------------------------------------------------------*/
typedef enum MotorCommand_t
{
	IDLE = 0,
	START = 1,
	STOP = 2,
	CHANGE_DIRECTION = 4,
}MotorCommand_t;
static volatile MotorCommand_t motor_command = IDLE;
DBG002_XSpyDataType xSpyApps[NO_XSPY_APPS];
int32_t MotorDir = 1;
extern PMSMFOCSL01_DynamicHandleType PMSMFOCSL01_DynamicHandle0;
extern MOTORLIBS_PIHandleType PMSMFOCSL01_PLLHandle0;

int main(void)
{

	uint16_t  PLLKp=PMSMFOCSL01_PLLHandle0.Kp; uint16_t PLLKi=PMSMFOCSL01_PLLHandle0.Ki;
	//	status_t status;		// Declaration of return variable for DAVE3 APIs (toggle comment if required)
	DBG002_VariableDescriptionType xSpyTable1[NUMBER_VARIABLES_XSPY1] = {
			XSPY_ADD_SCALED_UINT32("Motor Status", PMSMFOCSL01_DynamicHandle0.MotorStatus, 1.0),
			XSPY_ADD_SCALED_INT32("Speed reference",  PMSMFOCSL01_DynamicHandle0.EndSpeedRef, 0.508),//SPEED_SCALLING_FACTOR),
	 		XSPY_ADD_SCALED_UINT8("Motor Command", motor_command, 1.0),
	 		XSPY_ADD_SCALED_INT16("Motor Dir", MotorDir, 1.0),
	 		XSPY_ADD_SCALED_INT32("Actual speed", PMSMFOCSL01_DynamicHandle0.MotorSpeed, 0.508),//SPEED_SCALLING_FACTOR),
			//XSPY_ADD_SCALED_UINT32("V",  PMSMFOCSL01_DynamicHandle0.Amplitude, 1.0),
			//XSPY_ADD_SCALED_INT32("Speed value",  PMSMFOCSL01_DynamicHandle0.SpeedRef, 1.0),
	 		//XSPY_ADD_SCALED_INT16("FluxAngle", PMSMFOCSL01_DynamicHandle0.FluxAngle, 1.0),
	 		XSPY_ADD_SCALED_INT16("FluxAngle1", PMSMFOCSL01_DynamicHandle0.FluxAngle1, 1.0),
	 		XSPY_ADD_SCALED_INT32("MotorSpeedR", PMSMFOCSL01_DynamicHandle0.MotorSpeedR, 0.508),
	 		XSPY_ADD_SCALED_INT32("EAlpha", PMSMFOCSL01_DynamicHandle0.EAlpha, 1.0),
	 		XSPY_ADD_SCALED_INT32("EBeta", PMSMFOCSL01_DynamicHandle0.EBeta, 1.0),
	 		XSPY_ADD_SCALED_INT32("EPLL", PMSMFOCSL01_DynamicHandle0.E, 1.0),

	};
	DBG002_VariableDescriptionType xSpyTable2[NUMBER_VARIABLES_XSPY2] = {
			//XSPY_ADD_SCALED_INT32("Valpha", PMSMFOCSL01_DynamicHandle0.Valpha,1.0 ), //0.002965102686487406
			//XSPY_ADD_SCALED_INT32("Vbeta",  PMSMFOCSL01_DynamicHandle0.Vbeta, 1.0),
	 		//XSPY_ADD_SCALED_INT32("Ialpha", PMSMFOCSL01_DynamicHandle0.Ialpha, 1.0),  //0.00152587890625
	 		//XSPY_ADD_SCALED_INT32("Ibeta", PMSMFOCSL01_DynamicHandle0.Ibeta, 1.0),
	 		//XSPY_ADD_SCALED_INT32("FluxAlpha", PMSMFOCSL01_DynamicHandle0.FluxAlpha, 1.0),
	 		//XSPY_ADD_SCALED_INT32("FluxBeta", PMSMFOCSL01_DynamicHandle0.FluxBeta, 1.0),
			//XSPY_ADD_SCALED_UINT32("V",  PMSMFOCSL01_DynamicHandle0.Amplitude, 1.0),
			XSPY_ADD_SCALED_UINT16("Kp PLL", PLLKp , 1.0),
			XSPY_ADD_SCALED_UINT16("Ki PLL", PLLKi , 1.0),

	};
	PMSMFOCSL01_PLLHandle0.Kp=PLLKp;
	PMSMFOCSL01_PLLHandle0.Ki=PLLKi;
	DAVE_Init();			// Initialization of DAVE Apps
	// TODO Initialize xSPY
	DBG002_XspyInit(&xSpyApps[0], xSpyTable1, NUMBER_VARIABLES_XSPY1, DBG002_GID_XSPY1);
	DBG002_XspyInit(&xSpyApps[1], xSpyTable2, NUMBER_VARIABLES_XSPY2, DBG002_GID_XSPY2);
	PMSMFOCSL01_Handle0.H_Ptr->SpeedRef = 0;

	SystemCoreClockUpdate();
	SysTick_Config(SystemCoreClock / TICKS_PER_SECOND);

	while(1)
	{

	}
	return 0;
}

//1ms Interrupt Handler
void SysTick_Handler(void)
{
	static uint32_t ticks;

	if (ticks % TICKS_PER_SECOND == 0) {
		switch(motor_command)
		{
		case START:
			// Start the motor
			PMSMFOCSL01_MotorStart(&PMSMFOCSL01_Handle0);
			break;
		case STOP:
			// Stop the motor
			PMSMFOCSL01_MotorStop(&PMSMFOCSL01_Handle0);
			PMSMFOCSL01_Handle0.H_Ptr->SpeedRef = 0;
			PMSMFOCSL01_DynamicHandle0.MotorStatus &= ~(1 << 1);			// Clear the Status ON bit
			PMSMFOCSL01_DynamicHandle0.MotorStatus &= ~(1 << 2);			// Clear the Status Ramping Bit
			break;
		case CHANGE_DIRECTION:
			if (MotorDir == 1)
				// Change Motor Direction to reverse
				PMSMFOCSL01_SetMotDirection(&PMSMFOCSL01_Handle0, REVERSE_DIRECTION);
			else
				// Change Motor Direction to Forward
				PMSMFOCSL01_SetMotDirection(&PMSMFOCSL01_Handle0, FORWARD_DIRECTION);
			break;
		default:
			break;
		}
		motor_command = IDLE;
	}
	ticks++;
	// Get current Motor Direction

	PMSMFOCSL01_GetMotDirection(&PMSMFOCSL01_Handle0,&MotorDir);

	if(MotorDir  == -1)
		MotorDir  += 3;		// XSPY does not support negative number (reverse)
	// Update all the variables via XSPY protocol
	DBG002_XspyStreamData(&xSpyApps[0]);
	DBG002_XspyStreamData(&xSpyApps[1]);
}
